/* Settings.c generated by valac 0.56.19, the Vala compiler
 * generated from Settings.vala, do not modify */

#include <gio/gio.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <float.h>
#include <math.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>
#include <adwaita.h>

#define BUILD_DOMAIN "dev.geopjr.Tuba"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;
typedef struct _TubaSettingsPrivate TubaSettingsPrivate;

#define TUBA_SETTINGS_TYPE_ACCOUNT (tuba_settings_account_get_type ())
#define TUBA_SETTINGS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_SETTINGS_TYPE_ACCOUNT, TubaSettingsAccount))
#define TUBA_SETTINGS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_SETTINGS_TYPE_ACCOUNT, TubaSettingsAccountClass))
#define TUBA_SETTINGS_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_SETTINGS_TYPE_ACCOUNT))
#define TUBA_SETTINGS_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_SETTINGS_TYPE_ACCOUNT))
#define TUBA_SETTINGS_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_SETTINGS_TYPE_ACCOUNT, TubaSettingsAccountClass))

typedef struct _TubaSettingsAccount TubaSettingsAccount;
typedef struct _TubaSettingsAccountClass TubaSettingsAccountClass;
typedef enum  {
	TUBA_COLOR_SCHEME_SYSTEM,
	TUBA_COLOR_SCHEME_LIGHT,
	TUBA_COLOR_SCHEME_DARK
} TubaColorScheme;

#define TUBA_TYPE_COLOR_SCHEME (tuba_color_scheme_get_type ())
enum  {
	TUBA_SETTINGS_0_PROPERTY,
	TUBA_SETTINGS_ACTIVE_ACCOUNT_PROPERTY,
	TUBA_SETTINGS_DEFAULT_LANGUAGE_PROPERTY,
	TUBA_SETTINGS_DEFAULT_QUOTE_POLICY_PROPERTY,
	TUBA_SETTINGS_DEFAULT_POST_VISIBILITY_PROPERTY,
	TUBA_SETTINGS_DEFAULT_CONTENT_TYPE_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_SUGGESTIONS_PROPERTY,
	TUBA_SETTINGS_UNIFIEDPUSH_ENABLED_PROPERTY,
	TUBA_SETTINGS_MUTED_NOTIFICATION_TYPES_PROPERTY,
	TUBA_SETTINGS_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY,
	TUBA_SETTINGS_RECENT_SEARCHES_PROPERTY,
	TUBA_SETTINGS_NOTIFICATION_FILTERS_PROPERTY,
	TUBA_SETTINGS_FAVORITE_LISTS_IDS_PROPERTY,
	TUBA_SETTINGS_FAVORITE_TAGS_IDS_PROPERTY,
	TUBA_SETTINGS_HASHTAG_LISTS_PROPERTY,
	TUBA_SETTINGS_COLOR_SCHEME_PROPERTY,
	TUBA_SETTINGS_WORK_IN_BACKGROUND_PROPERTY,
	TUBA_SETTINGS_TIMELINE_PAGE_SIZE_PROPERTY,
	TUBA_SETTINGS_LIVE_UPDATES_PROPERTY,
	TUBA_SETTINGS_PUBLIC_LIVE_UPDATES_PROPERTY,
	TUBA_SETTINGS_SHOW_SPOILERS_PROPERTY,
	TUBA_SETTINGS_SHOW_PREVIEW_CARDS_PROPERTY,
	TUBA_SETTINGS_LARGER_FONT_SIZE_PROPERTY,
	TUBA_SETTINGS_LARGER_LINE_HEIGHT_PROPERTY,
	TUBA_SETTINGS_SCALE_EMOJI_HOVER_PROPERTY,
	TUBA_SETTINGS_AGGRESSIVE_RESOLVING_PROPERTY,
	TUBA_SETTINGS_STRIP_TRACKING_PROPERTY,
	TUBA_SETTINGS_LETTERBOX_MEDIA_PROPERTY,
	TUBA_SETTINGS_MEDIA_VIEWER_EXPAND_PICTURES_PROPERTY,
	TUBA_SETTINGS_ENLARGE_CUSTOM_EMOJIS_PROPERTY,
	TUBA_SETTINGS_USE_BLURHASH_PROPERTY,
	TUBA_SETTINGS_SHOW_SENSITIVE_MEDIA_PROPERTY,
	TUBA_SETTINGS_GROUP_PUSH_NOTIFICATIONS_PROPERTY,
	TUBA_SETTINGS_ADVANCED_BOOST_DIALOG_PROPERTY,
	TUBA_SETTINGS_REPLY_TO_OLD_POST_REMINDER_PROPERTY,
	TUBA_SETTINGS_BOOST_ALT_TEXT_REMINDER_PROPERTY,
	TUBA_SETTINGS_FETCH_REMOTE_MEDIA_REMINDER_PROPERTY,
	TUBA_SETTINGS_FETCH_REMOTE_MEDIA_DEFAULT_PROPERTY,
	TUBA_SETTINGS_COPY_PRIVATE_LINK_REMINDER_PROPERTY,
	TUBA_SETTINGS_SPELLCHECKER_ENABLED_PROPERTY,
	TUBA_SETTINGS_DARKEN_IMAGES_ON_DARK_MODE_PROPERTY,
	TUBA_SETTINGS_MEDIA_VIEWER_LAST_USED_VOLUME_PROPERTY,
	TUBA_SETTINGS_MONITOR_NETWORK_PROPERTY,
	TUBA_SETTINGS_PROXY_PROPERTY,
	TUBA_SETTINGS_DIM_TRIVIAL_NOTIFICATIONS_PROPERTY,
	TUBA_SETTINGS_ANALYTICS_PROPERTY,
	TUBA_SETTINGS_UPDATE_CONTRIBUTORS_PROPERTY,
	TUBA_SETTINGS_LAST_ANALYTICS_UPDATE_PROPERTY,
	TUBA_SETTINGS_LAST_CONTRIBUTORS_UPDATE_PROPERTY,
	TUBA_SETTINGS_CONTRIBUTORS_PROPERTY,
	TUBA_SETTINGS_STATUS_ARIA_VERBOSITY_PROPERTY,
	TUBA_SETTINGS_USE_IN_APP_BROWSER_IF_AVAILABLE_PROPERTY,
	TUBA_SETTINGS_COLLAPSE_LONG_POSTS_PROPERTY,
	TUBA_SETTINGS_SHOW_INTERACTION_COUNTERS_PROPERTY,
	TUBA_SETTINGS_EXTRACT_ALT_FROM_METADATA_PROPERTY,
	TUBA_SETTINGS_STATUS_FONT_SIZE_PROPERTY,
	TUBA_SETTINGS_NUM_PROPERTIES
};
static GParamSpec* tuba_settings_properties[TUBA_SETTINGS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _TubaSettingsAccountPrivate TubaSettingsAccountPrivate;
enum  {
	TUBA_SETTINGS_ACCOUNT_0_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_DEFAULT_QUOTE_POLICY_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_DEFAULT_LANGUAGE_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_DEFAULT_POST_VISIBILITY_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_DEFAULT_CONTENT_TYPE_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_ACCOUNT_SUGGESTIONS_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_MUTED_NOTIFICATION_TYPES_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_RECENT_SEARCHES_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_NOTIFICATION_FILTERS_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_FAVORITE_LISTS_IDS_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_FAVORITE_TAGS_IDS_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_HASHTAG_LISTS_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_UNIFIEDPUSH_ENABLED_PROPERTY,
	TUBA_SETTINGS_ACCOUNT_NUM_PROPERTIES
};
static GParamSpec* tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_NUM_PROPERTIES];
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

struct _TubaSettings {
	GSettings parent_instance;
	TubaSettingsPrivate * priv;
};

struct _TubaSettingsClass {
	GSettingsClass parent_class;
};

struct _TubaSettingsPrivate {
	TubaSettingsAccount* _active_account_settings;
	gchar* _active_account;
	TubaColorScheme _color_scheme;
	gboolean _work_in_background;
	gint _timeline_page_size;
	gboolean _live_updates;
	gboolean _public_live_updates;
	gboolean _show_spoilers;
	gboolean _show_preview_cards;
	gboolean _larger_font_size;
	gboolean _larger_line_height;
	gboolean _scale_emoji_hover;
	gboolean _aggressive_resolving;
	gboolean _strip_tracking;
	gboolean _letterbox_media;
	gboolean _media_viewer_expand_pictures;
	gboolean _enlarge_custom_emojis;
	gboolean _use_blurhash;
	gboolean _show_sensitive_media;
	gboolean _group_push_notifications;
	gboolean _advanced_boost_dialog;
	gboolean _reply_to_old_post_reminder;
	gboolean _boost_alt_text_reminder;
	gboolean _fetch_remote_media_reminder;
	gboolean _fetch_remote_media_default;
	gboolean _copy_private_link_reminder;
	gboolean _spellchecker_enabled;
	gboolean _darken_images_on_dark_mode;
	gdouble _media_viewer_last_used_volume;
	gboolean _monitor_network;
	gchar* _proxy;
	gboolean _dim_trivial_notifications;
	gboolean _analytics;
	gboolean _update_contributors;
	gchar* _last_analytics_update;
	gchar* _last_contributors_update;
	gchar** _contributors;
	gint _contributors_length1;
	gint __contributors_size_;
	gint _status_aria_verbosity;
	gboolean _use_in_app_browser_if_available;
	gboolean _collapse_long_posts;
	gboolean _show_interaction_counters;
	gboolean _extract_alt_from_metadata;
	gdouble _status_font_size;
	gchar** apply_instantly_keys;
	gint apply_instantly_keys_length1;
	gint _apply_instantly_keys_size_;
};

struct _TubaSettingsAccount {
	GSettings parent_instance;
	TubaSettingsAccountPrivate * priv;
};

struct _TubaSettingsAccountClass {
	GSettingsClass parent_class;
};

struct _TubaSettingsAccountPrivate {
	gchar* _default_quote_policy;
	gchar* _default_language;
	gchar* _default_post_visibility;
	gchar* _default_content_type;
	gboolean _account_suggestions;
	gchar** _muted_notification_types;
	gint _muted_notification_types_length1;
	gint __muted_notification_types_size_;
	gchar** _recently_used_custom_emojis;
	gint _recently_used_custom_emojis_length1;
	gint __recently_used_custom_emojis_size_;
	gchar** _recent_searches;
	gint _recent_searches_length1;
	gint __recent_searches_size_;
	gchar** _notification_filters;
	gint _notification_filters_length1;
	gint __notification_filters_size_;
	gchar** _favorite_lists_ids;
	gint _favorite_lists_ids_length1;
	gint __favorite_lists_ids_size_;
	gchar** _favorite_tags_ids;
	gint _favorite_tags_ids_length1;
	gint __favorite_tags_ids_size_;
	gchar** _hashtag_lists;
	gint _hashtag_lists_length1;
	gint __hashtag_lists_size_;
	gboolean _unifiedpush_enabled;
};

static gint TubaSettings_private_offset;
static gpointer tuba_settings_parent_class = NULL;
static gint TubaSettingsAccount_private_offset;
static gpointer tuba_settings_account_parent_class = NULL;

VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN GType tuba_settings_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettingsAccount, g_object_unref)
VALA_EXTERN GType tuba_color_scheme_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaSettings* tuba_settings_new (void);
VALA_EXTERN TubaSettings* tuba_settings_construct (GType object_type);
static void tuba_settings_init (TubaSettings* self,
                         const gchar* key,
                         gboolean apply_instantly);
static void tuba_settings_on_changed (TubaSettings* self,
                               const gchar* key);
static void _tuba_settings_on_changed_g_settings_changed (GSettings* _sender,
                                                   const gchar* key,
                                                   gpointer self);
static void _vala_array_add49 (gchar** * array,
                        gint* length,
                        gint* size,
                        gchar* value);
static gboolean _vala_string_array_contains (gchar* * stack,
                                      gssize stack_length,
                                      const gchar* needle);
VALA_EXTERN void tuba_settings_apply_all (TubaSettings* self);
static TubaSettingsAccount* tuba_settings_get_active_account_settings (TubaSettings* self);
VALA_EXTERN JsonBuilder* tuba_settings_to_debug_json (TubaSettings* self);
static void tuba_settings_set_active_account_settings (TubaSettings* self,
                                                TubaSettingsAccount* value);
VALA_EXTERN const gchar* tuba_settings_get_active_account (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_active_account (TubaSettings* self,
                                       const gchar* value);
VALA_EXTERN TubaSettingsAccount* tuba_settings_account_new (const gchar* id);
VALA_EXTERN TubaSettingsAccount* tuba_settings_account_construct (GType object_type,
                                                      const gchar* id);
VALA_EXTERN const gchar* tuba_settings_get_default_language (TubaSettings* self);
VALA_EXTERN const gchar* tuba_settings_account_get_default_language (TubaSettingsAccount* self);
VALA_EXTERN void tuba_settings_set_default_language (TubaSettings* self,
                                         const gchar* value);
VALA_EXTERN void tuba_settings_account_set_default_language (TubaSettingsAccount* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* tuba_settings_get_default_quote_policy (TubaSettings* self);
VALA_EXTERN const gchar* tuba_settings_account_get_default_quote_policy (TubaSettingsAccount* self);
VALA_EXTERN void tuba_settings_set_default_quote_policy (TubaSettings* self,
                                             const gchar* value);
VALA_EXTERN void tuba_settings_account_set_default_quote_policy (TubaSettingsAccount* self,
                                                     const gchar* value);
VALA_EXTERN const gchar* tuba_settings_get_default_post_visibility (TubaSettings* self);
VALA_EXTERN const gchar* tuba_settings_account_get_default_post_visibility (TubaSettingsAccount* self);
VALA_EXTERN void tuba_settings_set_default_post_visibility (TubaSettings* self,
                                                const gchar* value);
VALA_EXTERN void tuba_settings_account_set_default_post_visibility (TubaSettingsAccount* self,
                                                        const gchar* value);
VALA_EXTERN const gchar* tuba_settings_get_default_content_type (TubaSettings* self);
VALA_EXTERN const gchar* tuba_settings_account_get_default_content_type (TubaSettingsAccount* self);
VALA_EXTERN void tuba_settings_set_default_content_type (TubaSettings* self,
                                             const gchar* value);
VALA_EXTERN void tuba_settings_account_set_default_content_type (TubaSettingsAccount* self,
                                                     const gchar* value);
VALA_EXTERN gboolean tuba_settings_get_account_suggestions (TubaSettings* self);
VALA_EXTERN gboolean tuba_settings_account_get_account_suggestions (TubaSettingsAccount* self);
VALA_EXTERN void tuba_settings_set_account_suggestions (TubaSettings* self,
                                            gboolean value);
VALA_EXTERN void tuba_settings_account_set_account_suggestions (TubaSettingsAccount* self,
                                                    gboolean value);
VALA_EXTERN gboolean tuba_settings_get_unifiedpush_enabled (TubaSettings* self);
VALA_EXTERN gboolean tuba_settings_account_get_unifiedpush_enabled (TubaSettingsAccount* self);
VALA_EXTERN void tuba_settings_set_unifiedpush_enabled (TubaSettings* self,
                                            gboolean value);
VALA_EXTERN void tuba_settings_account_set_unifiedpush_enabled (TubaSettingsAccount* self,
                                                    gboolean value);
VALA_EXTERN gchar** tuba_settings_get_muted_notification_types (TubaSettings* self,
                                                    gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_muted_notification_types (TubaSettingsAccount* self,
                                                            gint* result_length1);
VALA_EXTERN void tuba_settings_set_muted_notification_types (TubaSettings* self,
                                                 gchar** value,
                                                 gint value_length1);
VALA_EXTERN void tuba_settings_account_set_muted_notification_types (TubaSettingsAccount* self,
                                                         gchar** value,
                                                         gint value_length1);
VALA_EXTERN gchar** tuba_settings_get_recently_used_custom_emojis (TubaSettings* self,
                                                       gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_recently_used_custom_emojis (TubaSettingsAccount* self,
                                                               gint* result_length1);
VALA_EXTERN void tuba_settings_set_recently_used_custom_emojis (TubaSettings* self,
                                                    gchar** value,
                                                    gint value_length1);
VALA_EXTERN void tuba_settings_account_set_recently_used_custom_emojis (TubaSettingsAccount* self,
                                                            gchar** value,
                                                            gint value_length1);
VALA_EXTERN gchar** tuba_settings_get_recent_searches (TubaSettings* self,
                                           gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_recent_searches (TubaSettingsAccount* self,
                                                   gint* result_length1);
VALA_EXTERN void tuba_settings_set_recent_searches (TubaSettings* self,
                                        gchar** value,
                                        gint value_length1);
VALA_EXTERN void tuba_settings_account_set_recent_searches (TubaSettingsAccount* self,
                                                gchar** value,
                                                gint value_length1);
VALA_EXTERN gchar** tuba_settings_get_notification_filters (TubaSettings* self,
                                                gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_notification_filters (TubaSettingsAccount* self,
                                                        gint* result_length1);
VALA_EXTERN void tuba_settings_set_notification_filters (TubaSettings* self,
                                             gchar** value,
                                             gint value_length1);
VALA_EXTERN void tuba_settings_account_set_notification_filters (TubaSettingsAccount* self,
                                                     gchar** value,
                                                     gint value_length1);
VALA_EXTERN gchar** tuba_settings_get_favorite_lists_ids (TubaSettings* self,
                                              gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_favorite_lists_ids (TubaSettingsAccount* self,
                                                      gint* result_length1);
VALA_EXTERN void tuba_settings_set_favorite_lists_ids (TubaSettings* self,
                                           gchar** value,
                                           gint value_length1);
VALA_EXTERN void tuba_settings_account_set_favorite_lists_ids (TubaSettingsAccount* self,
                                                   gchar** value,
                                                   gint value_length1);
VALA_EXTERN gchar** tuba_settings_get_favorite_tags_ids (TubaSettings* self,
                                             gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_favorite_tags_ids (TubaSettingsAccount* self,
                                                     gint* result_length1);
VALA_EXTERN void tuba_settings_set_favorite_tags_ids (TubaSettings* self,
                                          gchar** value,
                                          gint value_length1);
VALA_EXTERN void tuba_settings_account_set_favorite_tags_ids (TubaSettingsAccount* self,
                                                  gchar** value,
                                                  gint value_length1);
VALA_EXTERN gchar** tuba_settings_get_hashtag_lists (TubaSettings* self,
                                         gint* result_length1);
VALA_EXTERN gchar** tuba_settings_account_get_hashtag_lists (TubaSettingsAccount* self,
                                                 gint* result_length1);
VALA_EXTERN void tuba_settings_set_hashtag_lists (TubaSettings* self,
                                      gchar** value,
                                      gint value_length1);
VALA_EXTERN void tuba_settings_account_set_hashtag_lists (TubaSettingsAccount* self,
                                              gchar** value,
                                              gint value_length1);
VALA_EXTERN TubaColorScheme tuba_settings_get_color_scheme (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_color_scheme (TubaSettings* self,
                                     TubaColorScheme value);
VALA_EXTERN gboolean tuba_settings_get_work_in_background (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_work_in_background (TubaSettings* self,
                                           gboolean value);
VALA_EXTERN gint tuba_settings_get_timeline_page_size (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_timeline_page_size (TubaSettings* self,
                                           gint value);
VALA_EXTERN gboolean tuba_settings_get_live_updates (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_live_updates (TubaSettings* self,
                                     gboolean value);
VALA_EXTERN gboolean tuba_settings_get_public_live_updates (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_public_live_updates (TubaSettings* self,
                                            gboolean value);
VALA_EXTERN gboolean tuba_settings_get_show_spoilers (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_show_spoilers (TubaSettings* self,
                                      gboolean value);
VALA_EXTERN gboolean tuba_settings_get_show_preview_cards (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_show_preview_cards (TubaSettings* self,
                                           gboolean value);
VALA_EXTERN gboolean tuba_settings_get_larger_font_size (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_larger_font_size (TubaSettings* self,
                                         gboolean value);
VALA_EXTERN gboolean tuba_settings_get_larger_line_height (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_larger_line_height (TubaSettings* self,
                                           gboolean value);
VALA_EXTERN gboolean tuba_settings_get_scale_emoji_hover (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_scale_emoji_hover (TubaSettings* self,
                                          gboolean value);
VALA_EXTERN gboolean tuba_settings_get_aggressive_resolving (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_aggressive_resolving (TubaSettings* self,
                                             gboolean value);
VALA_EXTERN gboolean tuba_settings_get_strip_tracking (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_strip_tracking (TubaSettings* self,
                                       gboolean value);
VALA_EXTERN gboolean tuba_settings_get_letterbox_media (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_letterbox_media (TubaSettings* self,
                                        gboolean value);
VALA_EXTERN gboolean tuba_settings_get_media_viewer_expand_pictures (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_media_viewer_expand_pictures (TubaSettings* self,
                                                     gboolean value);
VALA_EXTERN gboolean tuba_settings_get_enlarge_custom_emojis (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_enlarge_custom_emojis (TubaSettings* self,
                                              gboolean value);
VALA_EXTERN gboolean tuba_settings_get_use_blurhash (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_use_blurhash (TubaSettings* self,
                                     gboolean value);
VALA_EXTERN gboolean tuba_settings_get_show_sensitive_media (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_show_sensitive_media (TubaSettings* self,
                                             gboolean value);
VALA_EXTERN gboolean tuba_settings_get_group_push_notifications (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_group_push_notifications (TubaSettings* self,
                                                 gboolean value);
VALA_EXTERN gboolean tuba_settings_get_advanced_boost_dialog (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_advanced_boost_dialog (TubaSettings* self,
                                              gboolean value);
VALA_EXTERN gboolean tuba_settings_get_reply_to_old_post_reminder (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_reply_to_old_post_reminder (TubaSettings* self,
                                                   gboolean value);
VALA_EXTERN gboolean tuba_settings_get_boost_alt_text_reminder (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_boost_alt_text_reminder (TubaSettings* self,
                                                gboolean value);
VALA_EXTERN gboolean tuba_settings_get_fetch_remote_media_reminder (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_fetch_remote_media_reminder (TubaSettings* self,
                                                    gboolean value);
VALA_EXTERN gboolean tuba_settings_get_fetch_remote_media_default (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_fetch_remote_media_default (TubaSettings* self,
                                                   gboolean value);
VALA_EXTERN gboolean tuba_settings_get_copy_private_link_reminder (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_copy_private_link_reminder (TubaSettings* self,
                                                   gboolean value);
VALA_EXTERN gboolean tuba_settings_get_spellchecker_enabled (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_spellchecker_enabled (TubaSettings* self,
                                             gboolean value);
VALA_EXTERN gboolean tuba_settings_get_darken_images_on_dark_mode (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_darken_images_on_dark_mode (TubaSettings* self,
                                                   gboolean value);
VALA_EXTERN gdouble tuba_settings_get_media_viewer_last_used_volume (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_media_viewer_last_used_volume (TubaSettings* self,
                                                      gdouble value);
VALA_EXTERN gboolean tuba_settings_get_monitor_network (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_monitor_network (TubaSettings* self,
                                        gboolean value);
VALA_EXTERN const gchar* tuba_settings_get_proxy (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_proxy (TubaSettings* self,
                              const gchar* value);
VALA_EXTERN gboolean tuba_settings_get_dim_trivial_notifications (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_dim_trivial_notifications (TubaSettings* self,
                                                  gboolean value);
VALA_EXTERN gboolean tuba_settings_get_analytics (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_analytics (TubaSettings* self,
                                  gboolean value);
VALA_EXTERN gboolean tuba_settings_get_update_contributors (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_update_contributors (TubaSettings* self,
                                            gboolean value);
VALA_EXTERN const gchar* tuba_settings_get_last_analytics_update (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_last_analytics_update (TubaSettings* self,
                                              const gchar* value);
VALA_EXTERN const gchar* tuba_settings_get_last_contributors_update (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_last_contributors_update (TubaSettings* self,
                                                 const gchar* value);
VALA_EXTERN gchar** tuba_settings_get_contributors (TubaSettings* self,
                                        gint* result_length1);
VALA_EXTERN void tuba_settings_set_contributors (TubaSettings* self,
                                     gchar** value,
                                     gint value_length1);
static gchar** _vala_array_dup26 (gchar** self,
                           gssize length);
VALA_EXTERN gint tuba_settings_get_status_aria_verbosity (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_status_aria_verbosity (TubaSettings* self,
                                              gint value);
VALA_EXTERN gboolean tuba_settings_get_use_in_app_browser_if_available (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_use_in_app_browser_if_available (TubaSettings* self,
                                                        gboolean value);
VALA_EXTERN gboolean tuba_settings_get_collapse_long_posts (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_collapse_long_posts (TubaSettings* self,
                                            gboolean value);
VALA_EXTERN gboolean tuba_settings_get_show_interaction_counters (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_show_interaction_counters (TubaSettings* self,
                                                  gboolean value);
VALA_EXTERN gboolean tuba_settings_get_extract_alt_from_metadata (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_extract_alt_from_metadata (TubaSettings* self,
                                                  gboolean value);
VALA_EXTERN gdouble tuba_settings_get_status_font_size (TubaSettings* self);
VALA_EXTERN void tuba_settings_set_status_font_size (TubaSettings* self,
                                         gdouble value);
static void tuba_settings_account_init (TubaSettingsAccount* self,
                                 const gchar* key);
static gchar** _vala_array_dup27 (gchar** self,
                           gssize length);
static gchar** _vala_array_dup28 (gchar** self,
                           gssize length);
static gchar** _vala_array_dup29 (gchar** self,
                           gssize length);
static gchar** _vala_array_dup30 (gchar** self,
                           gssize length);
static gchar** _vala_array_dup31 (gchar** self,
                           gssize length);
static gchar** _vala_array_dup32 (gchar** self,
                           gssize length);
static gchar** _vala_array_dup33 (gchar** self,
                           gssize length);
static void tuba_settings_account_finalize (GObject * obj);
static GType tuba_settings_account_get_type_once (void);
static void _vala_tuba_settings_account_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_tuba_settings_account_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);
static void tuba_settings_finalize (GObject * obj);
static GType tuba_settings_get_type_once (void);
static void _vala_tuba_settings_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_tuba_settings_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);
VALA_EXTERN gchar* tuba_color_scheme_to_string (TubaColorScheme self);
VALA_EXTERN AdwColorScheme tuba_color_scheme_to_adwaita_scheme (TubaColorScheme self);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static const gchar* TUBA_SETTINGS_KEYS_TO_INIT[37] = {"active-account", "color-scheme", "timeline-page-size", "live-updates", "public-live-updates", "show-spoilers", "show-preview-cards", "larger-font-size", "larger-line-height", "aggressive-resolving", "strip-tracking", "scale-emoji-hover", "letterbox-media", "media-viewer-expand-pictures", "enlarge-custom-emojis", "use-blurhash", "show-sensitive-media", "group-push-notifications", "advanced-boost-dialog", "reply-to-old-post-reminder", "boost-alt-text-reminder", "fetch-remote-media-reminder", "fetch-remote-media-default", "copy-private-link-reminder", "spellchecker-enabled", "darken-images-on-dark-mode", "media-viewer-last-used-volume", "monitor-network", "dim-trivial-notifications", "analytics", "update-contributors", "status-aria-verbosity", "use-in-app-browser-if-available", "collapse-long-posts", "show-interaction-counters", "extract-alt-from-metadata", "status-font-size"};
static const gchar* TUBA_SETTINGS_SENSITIVE_KEYS[5] = {"proxy", "active-account", "last-analytics-update", "last-contributors-update", "contributors"};
static const gchar* TUBA_SETTINGS_ACCOUNT_KEYS_TO_INIT[11] = {"default-post-visibility", "muted-notification-types", "default-content-type", "recently-used-custom-emojis", "recent-searches", "notification-filters", "account-suggestions", "favorite-lists-ids", "favorite-tags-ids", "hashtag-lists", "unifiedpush-enabled"};

static inline gpointer
tuba_settings_get_instance_private (TubaSettings* self)
{
	return G_STRUCT_MEMBER_P (self, TubaSettings_private_offset);
}

static void
_tuba_settings_on_changed_g_settings_changed (GSettings* _sender,
                                              const gchar* key,
                                              gpointer self)
{
	tuba_settings_on_changed ((TubaSettings*) self, key);
}

TubaSettings*
tuba_settings_construct (GType object_type)
{
	TubaSettings * self = NULL;
	self = (TubaSettings*) g_object_new (object_type, "schema-id", BUILD_DOMAIN, NULL);
	{
		const gchar** key_collection = NULL;
		gint key_collection_length1 = 0;
		gint _key_collection_size_ = 0;
		gint key_it = 0;
		key_collection = TUBA_SETTINGS_KEYS_TO_INIT;
		key_collection_length1 = G_N_ELEMENTS (TUBA_SETTINGS_KEYS_TO_INIT);
		for (key_it = 0; key_it < key_collection_length1; key_it = key_it + 1) {
			const gchar* key = NULL;
			key = key_collection[key_it];
			{
				const gchar* _tmp0_;
				_tmp0_ = key;
				tuba_settings_init (self, _tmp0_, FALSE);
			}
		}
	}
	tuba_settings_init (self, "work-in-background", TRUE);
	tuba_settings_init (self, "last-analytics-update", TRUE);
	tuba_settings_init (self, "last-contributors-update", TRUE);
	tuba_settings_init (self, "proxy", TRUE);
	tuba_settings_init (self, "contributors", TRUE);
	g_signal_connect_object ((GSettings*) self, "changed", (GCallback) _tuba_settings_on_changed_g_settings_changed, self, 0);
	return self;
}

TubaSettings*
tuba_settings_new (void)
{
	return tuba_settings_construct (TUBA_TYPE_SETTINGS);
}

static void
_vala_array_add49 (gchar** * array,
                   gint* length,
                   gint* size,
                   gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
tuba_settings_init (TubaSettings* self,
                    const gchar* key,
                    gboolean apply_instantly)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (key != NULL);
	g_settings_bind ((GSettings*) self, key, (GObject*) self, key, G_SETTINGS_BIND_DEFAULT);
	if (apply_instantly) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (key);
		_vala_array_add49 (&self->priv->apply_instantly_keys, &self->priv->apply_instantly_keys_length1, &self->priv->_apply_instantly_keys_size_, _tmp0_);
	}
}

static gboolean
_vala_string_array_contains (gchar* * stack,
                             gssize stack_length,
                             const gchar* needle)
{
	gssize i;
	for (i = 0; i < stack_length; i++) {
		if (g_strcmp0 (stack[i], needle) == 0) {
			return TRUE;
		}
	}
	return FALSE;
}

static void
tuba_settings_on_changed (TubaSettings* self,
                          const gchar* key)
{
	gchar** _tmp0_;
	gint _tmp0__length1;
	g_return_if_fail (self != NULL);
	g_return_if_fail (key != NULL);
	_tmp0_ = self->priv->apply_instantly_keys;
	_tmp0__length1 = self->priv->apply_instantly_keys_length1;
	if (_vala_string_array_contains (_tmp0_, _tmp0__length1, key)) {
		g_settings_apply ((GSettings*) self);
	}
}

void
tuba_settings_apply_all (TubaSettings* self)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	if (_tmp0_ != NULL) {
		TubaSettingsAccount* _tmp1_;
		_tmp1_ = self->priv->_active_account_settings;
		g_settings_apply ((GSettings*) _tmp1_);
	}
	g_settings_apply ((GSettings*) self);
}

JsonBuilder*
tuba_settings_to_debug_json (TubaSettings* self)
{
	JsonBuilder* builder = NULL;
	JsonBuilder* _tmp0_;
	JsonBuilder* _tmp1_;
	JsonBuilder* _tmp10_;
	JsonBuilder* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = json_builder_new ();
	builder = _tmp0_;
	_tmp1_ = builder;
	json_builder_begin_object (_tmp1_);
	{
		const gchar** key_collection = NULL;
		gint key_collection_length1 = 0;
		gint _key_collection_size_ = 0;
		gint key_it = 0;
		key_collection = TUBA_SETTINGS_KEYS_TO_INIT;
		key_collection_length1 = G_N_ELEMENTS (TUBA_SETTINGS_KEYS_TO_INIT);
		for (key_it = 0; key_it < key_collection_length1; key_it = key_it + 1) {
			gchar* _tmp2_;
			gchar* key = NULL;
			_tmp2_ = g_strdup (key_collection[key_it]);
			key = _tmp2_;
			{
				const gchar* _tmp3_;
				GValue val = {0};
				GValue _tmp4_ = {0};
				const gchar* _tmp5_;
				JsonBuilder* _tmp6_;
				const gchar* _tmp7_;
				JsonBuilder* _tmp8_;
				GValue _tmp9_;
				_tmp3_ = key;
				if (_vala_string_array_contains (TUBA_SETTINGS_SENSITIVE_KEYS, G_N_ELEMENTS (TUBA_SETTINGS_SENSITIVE_KEYS), _tmp3_)) {
					_g_free0 (key);
					continue;
				}
				g_value_init (&_tmp4_, G_TYPE_STRING);
				val = _tmp4_;
				_tmp5_ = key;
				g_object_get_property ((GObject*) self, _tmp5_, &val);
				_tmp6_ = builder;
				_tmp7_ = key;
				json_builder_set_member_name (_tmp6_, _tmp7_);
				_tmp8_ = builder;
				_tmp9_ = val;
				json_builder_add_string_value (_tmp8_, g_value_get_string (&_tmp9_));
				G_IS_VALUE (&val) ? (g_value_unset (&val), NULL) : NULL;
				_g_free0 (key);
			}
		}
	}
	_tmp10_ = builder;
	json_builder_end_object (_tmp10_);
	result = builder;
	return result;
}

static TubaSettingsAccount*
tuba_settings_get_active_account_settings (TubaSettings* self)
{
	TubaSettingsAccount* result;
	TubaSettingsAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_settings_set_active_account_settings (TubaSettings* self,
                                           TubaSettingsAccount* value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = _g_object_ref0 (value);
	_g_object_unref0 (self->priv->_active_account_settings);
	self->priv->_active_account_settings = _tmp0_;
}

const gchar*
tuba_settings_get_active_account (TubaSettings* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account;
	result = _tmp0_;
	return result;
}

void
tuba_settings_set_active_account (TubaSettings* self,
                                  const gchar* value)
{
	gchar* _tmp0_;
	TubaSettingsAccount* _tmp1_;
	TubaSettingsAccount* _tmp3_;
	TubaSettingsAccount* _tmp4_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_active_account);
	self->priv->_active_account = _tmp0_;
	_tmp1_ = self->priv->_active_account_settings;
	if (_tmp1_ != NULL) {
		TubaSettingsAccount* _tmp2_;
		_tmp2_ = self->priv->_active_account_settings;
		g_settings_apply ((GSettings*) _tmp2_);
	}
	_tmp3_ = tuba_settings_account_new (value);
	_tmp4_ = _tmp3_;
	tuba_settings_set_active_account_settings (self, _tmp4_);
	_g_object_unref0 (_tmp4_);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_ACTIVE_ACCOUNT_PROPERTY]);
}

const gchar*
tuba_settings_get_default_language (TubaSettings* self)
{
	const gchar* result;
	TubaSettingsAccount* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_default_language (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_settings_set_default_language (TubaSettings* self,
                                    const gchar* value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_default_language (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_LANGUAGE_PROPERTY]);
}

const gchar*
tuba_settings_get_default_quote_policy (TubaSettings* self)
{
	const gchar* result;
	TubaSettingsAccount* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_default_quote_policy (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_settings_set_default_quote_policy (TubaSettings* self,
                                        const gchar* value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_default_quote_policy (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_QUOTE_POLICY_PROPERTY]);
}

const gchar*
tuba_settings_get_default_post_visibility (TubaSettings* self)
{
	const gchar* result;
	TubaSettingsAccount* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_default_post_visibility (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_settings_set_default_post_visibility (TubaSettings* self,
                                           const gchar* value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_default_post_visibility (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_POST_VISIBILITY_PROPERTY]);
}

const gchar*
tuba_settings_get_default_content_type (TubaSettings* self)
{
	const gchar* result;
	TubaSettingsAccount* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_default_content_type (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_settings_set_default_content_type (TubaSettings* self,
                                        const gchar* value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_default_content_type (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_CONTENT_TYPE_PROPERTY]);
}

gboolean
tuba_settings_get_account_suggestions (TubaSettings* self)
{
	gboolean result;
	TubaSettingsAccount* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_account_suggestions (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_settings_set_account_suggestions (TubaSettings* self,
                                       gboolean value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_account_suggestions (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_ACCOUNT_SUGGESTIONS_PROPERTY]);
}

gboolean
tuba_settings_get_unifiedpush_enabled (TubaSettings* self)
{
	gboolean result;
	TubaSettingsAccount* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_unifiedpush_enabled (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_settings_set_unifiedpush_enabled (TubaSettings* self,
                                       gboolean value)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_unifiedpush_enabled (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_UNIFIEDPUSH_ENABLED_PROPERTY]);
}

gchar**
tuba_settings_get_muted_notification_types (TubaSettings* self,
                                            gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_muted_notification_types (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_muted_notification_types (TubaSettings* self,
                                            gchar** value,
                                            gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_muted_notification_types (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_MUTED_NOTIFICATION_TYPES_PROPERTY]);
}

gchar**
tuba_settings_get_recently_used_custom_emojis (TubaSettings* self,
                                               gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_recently_used_custom_emojis (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_recently_used_custom_emojis (TubaSettings* self,
                                               gchar** value,
                                               gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_recently_used_custom_emojis (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY]);
}

gchar**
tuba_settings_get_recent_searches (TubaSettings* self,
                                   gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_recent_searches (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_recent_searches (TubaSettings* self,
                                   gchar** value,
                                   gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_recent_searches (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_RECENT_SEARCHES_PROPERTY]);
}

gchar**
tuba_settings_get_notification_filters (TubaSettings* self,
                                        gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_notification_filters (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_notification_filters (TubaSettings* self,
                                        gchar** value,
                                        gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_notification_filters (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_NOTIFICATION_FILTERS_PROPERTY]);
}

gchar**
tuba_settings_get_favorite_lists_ids (TubaSettings* self,
                                      gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_favorite_lists_ids (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_favorite_lists_ids (TubaSettings* self,
                                      gchar** value,
                                      gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_favorite_lists_ids (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_FAVORITE_LISTS_IDS_PROPERTY]);
}

gchar**
tuba_settings_get_favorite_tags_ids (TubaSettings* self,
                                     gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_favorite_tags_ids (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_favorite_tags_ids (TubaSettings* self,
                                     gchar** value,
                                     gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_favorite_tags_ids (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_FAVORITE_TAGS_IDS_PROPERTY]);
}

gchar**
tuba_settings_get_hashtag_lists (TubaSettings* self,
                                 gint* result_length1)
{
	gchar** result;
	TubaSettingsAccount* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_active_account_settings;
	_tmp1_ = tuba_settings_account_get_hashtag_lists (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = _tmp3__length1;
	if (result_length1) {
		*result_length1 = _tmp4__length1;
	}
	result = _tmp4_;
	return result;
}

void
tuba_settings_set_hashtag_lists (TubaSettings* self,
                                 gchar** value,
                                 gint value_length1)
{
	TubaSettingsAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_active_account_settings;
	tuba_settings_account_set_hashtag_lists (_tmp0_, value, value_length1);
	g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_HASHTAG_LISTS_PROPERTY]);
}

TubaColorScheme
tuba_settings_get_color_scheme (TubaSettings* self)
{
	TubaColorScheme result;
	g_return_val_if_fail (self != NULL, 0);
	result = self->priv->_color_scheme;
	return result;
}

void
tuba_settings_set_color_scheme (TubaSettings* self,
                                TubaColorScheme value)
{
	TubaColorScheme old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_color_scheme (self);
	if (old_value != value) {
		self->priv->_color_scheme = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_COLOR_SCHEME_PROPERTY]);
	}
}

gboolean
tuba_settings_get_work_in_background (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_work_in_background;
	return result;
}

void
tuba_settings_set_work_in_background (TubaSettings* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_work_in_background (self);
	if (old_value != value) {
		self->priv->_work_in_background = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_WORK_IN_BACKGROUND_PROPERTY]);
	}
}

gint
tuba_settings_get_timeline_page_size (TubaSettings* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_timeline_page_size;
	return result;
}

void
tuba_settings_set_timeline_page_size (TubaSettings* self,
                                      gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_timeline_page_size (self);
	if (old_value != value) {
		self->priv->_timeline_page_size = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_TIMELINE_PAGE_SIZE_PROPERTY]);
	}
}

gboolean
tuba_settings_get_live_updates (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_live_updates;
	return result;
}

void
tuba_settings_set_live_updates (TubaSettings* self,
                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_live_updates (self);
	if (old_value != value) {
		self->priv->_live_updates = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_LIVE_UPDATES_PROPERTY]);
	}
}

gboolean
tuba_settings_get_public_live_updates (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_public_live_updates;
	return result;
}

void
tuba_settings_set_public_live_updates (TubaSettings* self,
                                       gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_public_live_updates (self);
	if (old_value != value) {
		self->priv->_public_live_updates = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_PUBLIC_LIVE_UPDATES_PROPERTY]);
	}
}

gboolean
tuba_settings_get_show_spoilers (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_spoilers;
	return result;
}

void
tuba_settings_set_show_spoilers (TubaSettings* self,
                                 gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_show_spoilers (self);
	if (old_value != value) {
		self->priv->_show_spoilers = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_SHOW_SPOILERS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_show_preview_cards (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_preview_cards;
	return result;
}

void
tuba_settings_set_show_preview_cards (TubaSettings* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_show_preview_cards (self);
	if (old_value != value) {
		self->priv->_show_preview_cards = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_SHOW_PREVIEW_CARDS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_larger_font_size (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_larger_font_size;
	return result;
}

void
tuba_settings_set_larger_font_size (TubaSettings* self,
                                    gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_larger_font_size (self);
	if (old_value != value) {
		self->priv->_larger_font_size = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_LARGER_FONT_SIZE_PROPERTY]);
	}
}

gboolean
tuba_settings_get_larger_line_height (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_larger_line_height;
	return result;
}

void
tuba_settings_set_larger_line_height (TubaSettings* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_larger_line_height (self);
	if (old_value != value) {
		self->priv->_larger_line_height = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_LARGER_LINE_HEIGHT_PROPERTY]);
	}
}

gboolean
tuba_settings_get_scale_emoji_hover (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_scale_emoji_hover;
	return result;
}

void
tuba_settings_set_scale_emoji_hover (TubaSettings* self,
                                     gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_scale_emoji_hover (self);
	if (old_value != value) {
		self->priv->_scale_emoji_hover = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_SCALE_EMOJI_HOVER_PROPERTY]);
	}
}

gboolean
tuba_settings_get_aggressive_resolving (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_aggressive_resolving;
	return result;
}

void
tuba_settings_set_aggressive_resolving (TubaSettings* self,
                                        gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_aggressive_resolving (self);
	if (old_value != value) {
		self->priv->_aggressive_resolving = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_AGGRESSIVE_RESOLVING_PROPERTY]);
	}
}

gboolean
tuba_settings_get_strip_tracking (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_strip_tracking;
	return result;
}

void
tuba_settings_set_strip_tracking (TubaSettings* self,
                                  gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_strip_tracking (self);
	if (old_value != value) {
		self->priv->_strip_tracking = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_STRIP_TRACKING_PROPERTY]);
	}
}

gboolean
tuba_settings_get_letterbox_media (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_letterbox_media;
	return result;
}

void
tuba_settings_set_letterbox_media (TubaSettings* self,
                                   gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_letterbox_media (self);
	if (old_value != value) {
		self->priv->_letterbox_media = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_LETTERBOX_MEDIA_PROPERTY]);
	}
}

gboolean
tuba_settings_get_media_viewer_expand_pictures (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_media_viewer_expand_pictures;
	return result;
}

void
tuba_settings_set_media_viewer_expand_pictures (TubaSettings* self,
                                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_media_viewer_expand_pictures (self);
	if (old_value != value) {
		self->priv->_media_viewer_expand_pictures = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_MEDIA_VIEWER_EXPAND_PICTURES_PROPERTY]);
	}
}

gboolean
tuba_settings_get_enlarge_custom_emojis (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_enlarge_custom_emojis;
	return result;
}

void
tuba_settings_set_enlarge_custom_emojis (TubaSettings* self,
                                         gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_enlarge_custom_emojis (self);
	if (old_value != value) {
		self->priv->_enlarge_custom_emojis = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_ENLARGE_CUSTOM_EMOJIS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_use_blurhash (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_use_blurhash;
	return result;
}

void
tuba_settings_set_use_blurhash (TubaSettings* self,
                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_use_blurhash (self);
	if (old_value != value) {
		self->priv->_use_blurhash = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_USE_BLURHASH_PROPERTY]);
	}
}

gboolean
tuba_settings_get_show_sensitive_media (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_sensitive_media;
	return result;
}

void
tuba_settings_set_show_sensitive_media (TubaSettings* self,
                                        gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_show_sensitive_media (self);
	if (old_value != value) {
		self->priv->_show_sensitive_media = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_SHOW_SENSITIVE_MEDIA_PROPERTY]);
	}
}

gboolean
tuba_settings_get_group_push_notifications (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_group_push_notifications;
	return result;
}

void
tuba_settings_set_group_push_notifications (TubaSettings* self,
                                            gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_group_push_notifications (self);
	if (old_value != value) {
		self->priv->_group_push_notifications = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_GROUP_PUSH_NOTIFICATIONS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_advanced_boost_dialog (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_advanced_boost_dialog;
	return result;
}

void
tuba_settings_set_advanced_boost_dialog (TubaSettings* self,
                                         gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_advanced_boost_dialog (self);
	if (old_value != value) {
		self->priv->_advanced_boost_dialog = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_ADVANCED_BOOST_DIALOG_PROPERTY]);
	}
}

gboolean
tuba_settings_get_reply_to_old_post_reminder (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_reply_to_old_post_reminder;
	return result;
}

void
tuba_settings_set_reply_to_old_post_reminder (TubaSettings* self,
                                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_reply_to_old_post_reminder (self);
	if (old_value != value) {
		self->priv->_reply_to_old_post_reminder = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_REPLY_TO_OLD_POST_REMINDER_PROPERTY]);
	}
}

gboolean
tuba_settings_get_boost_alt_text_reminder (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_boost_alt_text_reminder;
	return result;
}

void
tuba_settings_set_boost_alt_text_reminder (TubaSettings* self,
                                           gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_boost_alt_text_reminder (self);
	if (old_value != value) {
		self->priv->_boost_alt_text_reminder = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_BOOST_ALT_TEXT_REMINDER_PROPERTY]);
	}
}

gboolean
tuba_settings_get_fetch_remote_media_reminder (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_fetch_remote_media_reminder;
	return result;
}

void
tuba_settings_set_fetch_remote_media_reminder (TubaSettings* self,
                                               gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_fetch_remote_media_reminder (self);
	if (old_value != value) {
		self->priv->_fetch_remote_media_reminder = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_FETCH_REMOTE_MEDIA_REMINDER_PROPERTY]);
	}
}

gboolean
tuba_settings_get_fetch_remote_media_default (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_fetch_remote_media_default;
	return result;
}

void
tuba_settings_set_fetch_remote_media_default (TubaSettings* self,
                                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_fetch_remote_media_default (self);
	if (old_value != value) {
		self->priv->_fetch_remote_media_default = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_FETCH_REMOTE_MEDIA_DEFAULT_PROPERTY]);
	}
}

gboolean
tuba_settings_get_copy_private_link_reminder (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_copy_private_link_reminder;
	return result;
}

void
tuba_settings_set_copy_private_link_reminder (TubaSettings* self,
                                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_copy_private_link_reminder (self);
	if (old_value != value) {
		self->priv->_copy_private_link_reminder = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_COPY_PRIVATE_LINK_REMINDER_PROPERTY]);
	}
}

gboolean
tuba_settings_get_spellchecker_enabled (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_spellchecker_enabled;
	return result;
}

void
tuba_settings_set_spellchecker_enabled (TubaSettings* self,
                                        gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_spellchecker_enabled (self);
	if (old_value != value) {
		self->priv->_spellchecker_enabled = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_SPELLCHECKER_ENABLED_PROPERTY]);
	}
}

gboolean
tuba_settings_get_darken_images_on_dark_mode (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_darken_images_on_dark_mode;
	return result;
}

void
tuba_settings_set_darken_images_on_dark_mode (TubaSettings* self,
                                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_darken_images_on_dark_mode (self);
	if (old_value != value) {
		self->priv->_darken_images_on_dark_mode = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_DARKEN_IMAGES_ON_DARK_MODE_PROPERTY]);
	}
}

gdouble
tuba_settings_get_media_viewer_last_used_volume (TubaSettings* self)
{
	gdouble result;
	g_return_val_if_fail (self != NULL, -1.0);
	result = self->priv->_media_viewer_last_used_volume;
	return result;
}

void
tuba_settings_set_media_viewer_last_used_volume (TubaSettings* self,
                                                 gdouble value)
{
	gdouble old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_media_viewer_last_used_volume (self);
	if (old_value != value) {
		self->priv->_media_viewer_last_used_volume = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_MEDIA_VIEWER_LAST_USED_VOLUME_PROPERTY]);
	}
}

gboolean
tuba_settings_get_monitor_network (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_monitor_network;
	return result;
}

void
tuba_settings_set_monitor_network (TubaSettings* self,
                                   gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_monitor_network (self);
	if (old_value != value) {
		self->priv->_monitor_network = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_MONITOR_NETWORK_PROPERTY]);
	}
}

const gchar*
tuba_settings_get_proxy (TubaSettings* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_proxy;
	result = _tmp0_;
	return result;
}

void
tuba_settings_set_proxy (TubaSettings* self,
                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_proxy (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_proxy);
		self->priv->_proxy = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_PROXY_PROPERTY]);
	}
}

gboolean
tuba_settings_get_dim_trivial_notifications (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_dim_trivial_notifications;
	return result;
}

void
tuba_settings_set_dim_trivial_notifications (TubaSettings* self,
                                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_dim_trivial_notifications (self);
	if (old_value != value) {
		self->priv->_dim_trivial_notifications = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_DIM_TRIVIAL_NOTIFICATIONS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_analytics (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_analytics;
	return result;
}

void
tuba_settings_set_analytics (TubaSettings* self,
                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_analytics (self);
	if (old_value != value) {
		self->priv->_analytics = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_ANALYTICS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_update_contributors (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_update_contributors;
	return result;
}

void
tuba_settings_set_update_contributors (TubaSettings* self,
                                       gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_update_contributors (self);
	if (old_value != value) {
		self->priv->_update_contributors = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_UPDATE_CONTRIBUTORS_PROPERTY]);
	}
}

const gchar*
tuba_settings_get_last_analytics_update (TubaSettings* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_last_analytics_update;
	result = _tmp0_;
	return result;
}

void
tuba_settings_set_last_analytics_update (TubaSettings* self,
                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_last_analytics_update (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_last_analytics_update);
		self->priv->_last_analytics_update = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_LAST_ANALYTICS_UPDATE_PROPERTY]);
	}
}

const gchar*
tuba_settings_get_last_contributors_update (TubaSettings* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_last_contributors_update;
	result = _tmp0_;
	return result;
}

void
tuba_settings_set_last_contributors_update (TubaSettings* self,
                                            const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_last_contributors_update (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_last_contributors_update);
		self->priv->_last_contributors_update = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_LAST_CONTRIBUTORS_UPDATE_PROPERTY]);
	}
}

gchar**
tuba_settings_get_contributors (TubaSettings* self,
                                gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_contributors;
	_tmp0__length1 = self->priv->_contributors_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup26 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_set_contributors (TubaSettings* self,
                                gchar** value,
                                gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_contributors (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup26 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_contributors = (_vala_array_free (self->priv->_contributors, self->priv->_contributors_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_contributors = _tmp0_;
		self->priv->_contributors_length1 = _tmp0__length1;
		self->priv->__contributors_size_ = self->priv->_contributors_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_CONTRIBUTORS_PROPERTY]);
	}
}

gint
tuba_settings_get_status_aria_verbosity (TubaSettings* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_status_aria_verbosity;
	return result;
}

void
tuba_settings_set_status_aria_verbosity (TubaSettings* self,
                                         gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_status_aria_verbosity (self);
	if (old_value != value) {
		self->priv->_status_aria_verbosity = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_STATUS_ARIA_VERBOSITY_PROPERTY]);
	}
}

gboolean
tuba_settings_get_use_in_app_browser_if_available (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_use_in_app_browser_if_available;
	return result;
}

void
tuba_settings_set_use_in_app_browser_if_available (TubaSettings* self,
                                                   gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_use_in_app_browser_if_available (self);
	if (old_value != value) {
		self->priv->_use_in_app_browser_if_available = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_USE_IN_APP_BROWSER_IF_AVAILABLE_PROPERTY]);
	}
}

gboolean
tuba_settings_get_collapse_long_posts (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_collapse_long_posts;
	return result;
}

void
tuba_settings_set_collapse_long_posts (TubaSettings* self,
                                       gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_collapse_long_posts (self);
	if (old_value != value) {
		self->priv->_collapse_long_posts = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_COLLAPSE_LONG_POSTS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_show_interaction_counters (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_interaction_counters;
	return result;
}

void
tuba_settings_set_show_interaction_counters (TubaSettings* self,
                                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_show_interaction_counters (self);
	if (old_value != value) {
		self->priv->_show_interaction_counters = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_SHOW_INTERACTION_COUNTERS_PROPERTY]);
	}
}

gboolean
tuba_settings_get_extract_alt_from_metadata (TubaSettings* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_extract_alt_from_metadata;
	return result;
}

void
tuba_settings_set_extract_alt_from_metadata (TubaSettings* self,
                                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_extract_alt_from_metadata (self);
	if (old_value != value) {
		self->priv->_extract_alt_from_metadata = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_EXTRACT_ALT_FROM_METADATA_PROPERTY]);
	}
}

gdouble
tuba_settings_get_status_font_size (TubaSettings* self)
{
	gdouble result;
	g_return_val_if_fail (self != NULL, -1.0);
	result = self->priv->_status_font_size;
	return result;
}

void
tuba_settings_set_status_font_size (TubaSettings* self,
                                    gdouble value)
{
	gdouble old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_get_status_font_size (self);
	if (old_value != value) {
		self->priv->_status_font_size = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_properties[TUBA_SETTINGS_STATUS_FONT_SIZE_PROPERTY]);
	}
}

static inline gpointer
tuba_settings_account_get_instance_private (TubaSettingsAccount* self)
{
	return G_STRUCT_MEMBER_P (self, TubaSettingsAccount_private_offset);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	if ((*((gchar*) self)) == '\0') {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = (*((gchar*) old)) == '\0';
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (self);
		result = _tmp2_;
		return result;
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp3_ = g_regex_escape_string (old, -1);
		_tmp4_ = _tmp3_;
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error0_);
		_tmp6_ = _tmp5_;
		_g_free0 (_tmp4_);
		regex = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp8_ = regex;
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error0_);
		_tmp7_ = _tmp9_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp10_ = _tmp7_;
		_tmp7_ = NULL;
		result = _tmp10_;
		_g_free0 (_tmp7_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		g_clear_error (&_inner_error0_);
		g_assert_not_reached ();
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return NULL;
}

TubaSettingsAccount*
tuba_settings_account_construct (GType object_type,
                                 const gchar* id)
{
	TubaSettingsAccount * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	g_return_val_if_fail (id != NULL, NULL);
	_tmp0_ = string_to_string (BUILD_DOMAIN);
	_tmp1_ = g_strconcat (_tmp0_, ".Account", NULL);
	_tmp2_ = _tmp1_;
	_tmp3_ = string_replace (BUILD_DOMAIN, ".", "/");
	_tmp4_ = _tmp3_;
	_tmp5_ = string_to_string (_tmp4_);
	_tmp6_ = string_to_string (id);
	_tmp7_ = g_strconcat ("/", _tmp5_, "/accounts/", _tmp6_, "/", NULL);
	_tmp8_ = _tmp7_;
	self = (TubaSettingsAccount*) g_object_new (object_type, "schema-id", _tmp2_, "path", _tmp8_, NULL);
	_g_free0 (_tmp8_);
	_g_free0 (_tmp4_);
	_g_free0 (_tmp2_);
	g_settings_delay ((GSettings*) self);
	{
		const gchar** key_collection = NULL;
		gint key_collection_length1 = 0;
		gint _key_collection_size_ = 0;
		gint key_it = 0;
		key_collection = TUBA_SETTINGS_ACCOUNT_KEYS_TO_INIT;
		key_collection_length1 = G_N_ELEMENTS (TUBA_SETTINGS_ACCOUNT_KEYS_TO_INIT);
		for (key_it = 0; key_it < key_collection_length1; key_it = key_it + 1) {
			const gchar* key = NULL;
			key = key_collection[key_it];
			{
				const gchar* _tmp9_;
				_tmp9_ = key;
				tuba_settings_account_init (self, _tmp9_);
			}
		}
	}
	return self;
}

TubaSettingsAccount*
tuba_settings_account_new (const gchar* id)
{
	return tuba_settings_account_construct (TUBA_SETTINGS_TYPE_ACCOUNT, id);
}

static void
tuba_settings_account_init (TubaSettingsAccount* self,
                            const gchar* key)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (key != NULL);
	g_settings_bind ((GSettings*) self, key, (GObject*) self, key, G_SETTINGS_BIND_DEFAULT);
}

const gchar*
tuba_settings_account_get_default_quote_policy (TubaSettingsAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_default_quote_policy;
	result = _tmp0_;
	return result;
}

void
tuba_settings_account_set_default_quote_policy (TubaSettingsAccount* self,
                                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_default_quote_policy (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_default_quote_policy);
		self->priv->_default_quote_policy = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_QUOTE_POLICY_PROPERTY]);
	}
}

const gchar*
tuba_settings_account_get_default_language (TubaSettingsAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_default_language;
	result = _tmp0_;
	return result;
}

void
tuba_settings_account_set_default_language (TubaSettingsAccount* self,
                                            const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_default_language (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_default_language);
		self->priv->_default_language = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_LANGUAGE_PROPERTY]);
	}
}

const gchar*
tuba_settings_account_get_default_post_visibility (TubaSettingsAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_default_post_visibility;
	result = _tmp0_;
	return result;
}

void
tuba_settings_account_set_default_post_visibility (TubaSettingsAccount* self,
                                                   const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_default_post_visibility (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_default_post_visibility);
		self->priv->_default_post_visibility = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_POST_VISIBILITY_PROPERTY]);
	}
}

const gchar*
tuba_settings_account_get_default_content_type (TubaSettingsAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_default_content_type;
	result = _tmp0_;
	return result;
}

void
tuba_settings_account_set_default_content_type (TubaSettingsAccount* self,
                                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_default_content_type (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_default_content_type);
		self->priv->_default_content_type = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_CONTENT_TYPE_PROPERTY]);
	}
}

gboolean
tuba_settings_account_get_account_suggestions (TubaSettingsAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_account_suggestions;
	return result;
}

void
tuba_settings_account_set_account_suggestions (TubaSettingsAccount* self,
                                               gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_account_suggestions (self);
	if (old_value != value) {
		self->priv->_account_suggestions = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_ACCOUNT_SUGGESTIONS_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_muted_notification_types (TubaSettingsAccount* self,
                                                    gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_muted_notification_types;
	_tmp0__length1 = self->priv->_muted_notification_types_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup27 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_muted_notification_types (TubaSettingsAccount* self,
                                                    gchar** value,
                                                    gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_muted_notification_types (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup27 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_muted_notification_types = (_vala_array_free (self->priv->_muted_notification_types, self->priv->_muted_notification_types_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_muted_notification_types = _tmp0_;
		self->priv->_muted_notification_types_length1 = _tmp0__length1;
		self->priv->__muted_notification_types_size_ = self->priv->_muted_notification_types_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_MUTED_NOTIFICATION_TYPES_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_recently_used_custom_emojis (TubaSettingsAccount* self,
                                                       gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_recently_used_custom_emojis;
	_tmp0__length1 = self->priv->_recently_used_custom_emojis_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup28 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_recently_used_custom_emojis (TubaSettingsAccount* self,
                                                       gchar** value,
                                                       gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_recently_used_custom_emojis (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup28 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_recently_used_custom_emojis = (_vala_array_free (self->priv->_recently_used_custom_emojis, self->priv->_recently_used_custom_emojis_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_recently_used_custom_emojis = _tmp0_;
		self->priv->_recently_used_custom_emojis_length1 = _tmp0__length1;
		self->priv->__recently_used_custom_emojis_size_ = self->priv->_recently_used_custom_emojis_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_recent_searches (TubaSettingsAccount* self,
                                           gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_recent_searches;
	_tmp0__length1 = self->priv->_recent_searches_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup29 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_recent_searches (TubaSettingsAccount* self,
                                           gchar** value,
                                           gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_recent_searches (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup29 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_recent_searches = (_vala_array_free (self->priv->_recent_searches, self->priv->_recent_searches_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_recent_searches = _tmp0_;
		self->priv->_recent_searches_length1 = _tmp0__length1;
		self->priv->__recent_searches_size_ = self->priv->_recent_searches_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_RECENT_SEARCHES_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_notification_filters (TubaSettingsAccount* self,
                                                gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_notification_filters;
	_tmp0__length1 = self->priv->_notification_filters_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup30 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_notification_filters (TubaSettingsAccount* self,
                                                gchar** value,
                                                gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_notification_filters (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup30 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_notification_filters = (_vala_array_free (self->priv->_notification_filters, self->priv->_notification_filters_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_notification_filters = _tmp0_;
		self->priv->_notification_filters_length1 = _tmp0__length1;
		self->priv->__notification_filters_size_ = self->priv->_notification_filters_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_NOTIFICATION_FILTERS_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_favorite_lists_ids (TubaSettingsAccount* self,
                                              gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_favorite_lists_ids;
	_tmp0__length1 = self->priv->_favorite_lists_ids_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup31 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_favorite_lists_ids (TubaSettingsAccount* self,
                                              gchar** value,
                                              gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_favorite_lists_ids (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup31 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_favorite_lists_ids = (_vala_array_free (self->priv->_favorite_lists_ids, self->priv->_favorite_lists_ids_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_favorite_lists_ids = _tmp0_;
		self->priv->_favorite_lists_ids_length1 = _tmp0__length1;
		self->priv->__favorite_lists_ids_size_ = self->priv->_favorite_lists_ids_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_FAVORITE_LISTS_IDS_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_favorite_tags_ids (TubaSettingsAccount* self,
                                             gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_favorite_tags_ids;
	_tmp0__length1 = self->priv->_favorite_tags_ids_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup32 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_favorite_tags_ids (TubaSettingsAccount* self,
                                             gchar** value,
                                             gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_favorite_tags_ids (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup32 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_favorite_tags_ids = (_vala_array_free (self->priv->_favorite_tags_ids, self->priv->_favorite_tags_ids_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_favorite_tags_ids = _tmp0_;
		self->priv->_favorite_tags_ids_length1 = _tmp0__length1;
		self->priv->__favorite_tags_ids_size_ = self->priv->_favorite_tags_ids_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_FAVORITE_TAGS_IDS_PROPERTY]);
	}
}

gchar**
tuba_settings_account_get_hashtag_lists (TubaSettingsAccount* self,
                                         gint* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_hashtag_lists;
	_tmp0__length1 = self->priv->_hashtag_lists_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}

static gchar**
_vala_array_dup33 (gchar** self,
                   gssize length)
{
	if (length >= 0) {
		gchar** result;
		gssize i;
		result = g_new0 (gchar*, length + 1);
		for (i = 0; i < length; i++) {
			gchar* _tmp0_;
			_tmp0_ = g_strdup (self[i]);
			result[i] = _tmp0_;
		}
		return result;
	}
	return NULL;
}

void
tuba_settings_account_set_hashtag_lists (TubaSettingsAccount* self,
                                         gchar** value,
                                         gint value_length1)
{
	gchar** old_value;
	gint old_value_length;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_hashtag_lists (self, &old_value_length);
	if (old_value != value) {
		gchar** _tmp0_;
		gint _tmp0__length1;
		_tmp0_ = (value != NULL) ? _vala_array_dup33 (value, value_length1) : value;
		_tmp0__length1 = value_length1;
		self->priv->_hashtag_lists = (_vala_array_free (self->priv->_hashtag_lists, self->priv->_hashtag_lists_length1, (GDestroyNotify) g_free), NULL);
		self->priv->_hashtag_lists = _tmp0_;
		self->priv->_hashtag_lists_length1 = _tmp0__length1;
		self->priv->__hashtag_lists_size_ = self->priv->_hashtag_lists_length1;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_HASHTAG_LISTS_PROPERTY]);
	}
}

gboolean
tuba_settings_account_get_unifiedpush_enabled (TubaSettingsAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_unifiedpush_enabled;
	return result;
}

void
tuba_settings_account_set_unifiedpush_enabled (TubaSettingsAccount* self,
                                               gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_settings_account_get_unifiedpush_enabled (self);
	if (old_value != value) {
		self->priv->_unifiedpush_enabled = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_UNIFIEDPUSH_ENABLED_PROPERTY]);
	}
}

static void
tuba_settings_account_class_init (TubaSettingsAccountClass * klass,
                                  gpointer klass_data)
{
	tuba_settings_account_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaSettingsAccount_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_settings_account_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_settings_account_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_settings_account_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_DEFAULT_QUOTE_POLICY_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_QUOTE_POLICY_PROPERTY] = g_param_spec_string ("default-quote-policy", "default-quote-policy", "default-quote-policy", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_DEFAULT_LANGUAGE_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_LANGUAGE_PROPERTY] = g_param_spec_string ("default-language", "default-language", "default-language", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_DEFAULT_POST_VISIBILITY_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_POST_VISIBILITY_PROPERTY] = g_param_spec_string ("default-post-visibility", "default-post-visibility", "default-post-visibility", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_DEFAULT_CONTENT_TYPE_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_DEFAULT_CONTENT_TYPE_PROPERTY] = g_param_spec_string ("default-content-type", "default-content-type", "default-content-type", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_ACCOUNT_SUGGESTIONS_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_ACCOUNT_SUGGESTIONS_PROPERTY] = g_param_spec_boolean ("account-suggestions", "account-suggestions", "account-suggestions", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_MUTED_NOTIFICATION_TYPES_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_MUTED_NOTIFICATION_TYPES_PROPERTY] = g_param_spec_boxed ("muted-notification-types", "muted-notification-types", "muted-notification-types", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY] = g_param_spec_boxed ("recently-used-custom-emojis", "recently-used-custom-emojis", "recently-used-custom-emojis", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_RECENT_SEARCHES_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_RECENT_SEARCHES_PROPERTY] = g_param_spec_boxed ("recent-searches", "recent-searches", "recent-searches", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_NOTIFICATION_FILTERS_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_NOTIFICATION_FILTERS_PROPERTY] = g_param_spec_boxed ("notification-filters", "notification-filters", "notification-filters", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_FAVORITE_LISTS_IDS_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_FAVORITE_LISTS_IDS_PROPERTY] = g_param_spec_boxed ("favorite-lists-ids", "favorite-lists-ids", "favorite-lists-ids", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_FAVORITE_TAGS_IDS_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_FAVORITE_TAGS_IDS_PROPERTY] = g_param_spec_boxed ("favorite-tags-ids", "favorite-tags-ids", "favorite-tags-ids", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_HASHTAG_LISTS_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_HASHTAG_LISTS_PROPERTY] = g_param_spec_boxed ("hashtag-lists", "hashtag-lists", "hashtag-lists", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_UNIFIEDPUSH_ENABLED_PROPERTY, tuba_settings_account_properties[TUBA_SETTINGS_ACCOUNT_UNIFIEDPUSH_ENABLED_PROPERTY] = g_param_spec_boolean ("unifiedpush-enabled", "unifiedpush-enabled", "unifiedpush-enabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_settings_account_instance_init (TubaSettingsAccount * self,
                                     gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gchar** _tmp9_;
	gchar** _tmp10_;
	self->priv = tuba_settings_account_get_instance_private (self);
	_tmp0_ = g_strdup ("followers");
	self->priv->_default_quote_policy = _tmp0_;
	_tmp1_ = g_strdup ("en");
	self->priv->_default_language = _tmp1_;
	_tmp2_ = g_strdup ("public");
	self->priv->_default_post_visibility = _tmp2_;
	_tmp3_ = g_strdup ("text/plain");
	self->priv->_default_content_type = _tmp3_;
	self->priv->_account_suggestions = TRUE;
	_tmp4_ = g_new0 (gchar*, 0 + 1);
	self->priv->_muted_notification_types = _tmp4_;
	self->priv->_muted_notification_types_length1 = 0;
	self->priv->__muted_notification_types_size_ = self->priv->_muted_notification_types_length1;
	_tmp5_ = g_new0 (gchar*, 0 + 1);
	self->priv->_recently_used_custom_emojis = _tmp5_;
	self->priv->_recently_used_custom_emojis_length1 = 0;
	self->priv->__recently_used_custom_emojis_size_ = self->priv->_recently_used_custom_emojis_length1;
	_tmp6_ = g_new0 (gchar*, 0 + 1);
	self->priv->_recent_searches = _tmp6_;
	self->priv->_recent_searches_length1 = 0;
	self->priv->__recent_searches_size_ = self->priv->_recent_searches_length1;
	_tmp7_ = g_new0 (gchar*, 0 + 1);
	self->priv->_notification_filters = _tmp7_;
	self->priv->_notification_filters_length1 = 0;
	self->priv->__notification_filters_size_ = self->priv->_notification_filters_length1;
	_tmp8_ = g_new0 (gchar*, 0 + 1);
	self->priv->_favorite_lists_ids = _tmp8_;
	self->priv->_favorite_lists_ids_length1 = 0;
	self->priv->__favorite_lists_ids_size_ = self->priv->_favorite_lists_ids_length1;
	_tmp9_ = g_new0 (gchar*, 0 + 1);
	self->priv->_favorite_tags_ids = _tmp9_;
	self->priv->_favorite_tags_ids_length1 = 0;
	self->priv->__favorite_tags_ids_size_ = self->priv->_favorite_tags_ids_length1;
	_tmp10_ = g_new0 (gchar*, 0 + 1);
	self->priv->_hashtag_lists = _tmp10_;
	self->priv->_hashtag_lists_length1 = 0;
	self->priv->__hashtag_lists_size_ = self->priv->_hashtag_lists_length1;
	self->priv->_unifiedpush_enabled = FALSE;
}

static void
tuba_settings_account_finalize (GObject * obj)
{
	TubaSettingsAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_SETTINGS_TYPE_ACCOUNT, TubaSettingsAccount);
	_g_free0 (self->priv->_default_quote_policy);
	_g_free0 (self->priv->_default_language);
	_g_free0 (self->priv->_default_post_visibility);
	_g_free0 (self->priv->_default_content_type);
	self->priv->_muted_notification_types = (_vala_array_free (self->priv->_muted_notification_types, self->priv->_muted_notification_types_length1, (GDestroyNotify) g_free), NULL);
	self->priv->_recently_used_custom_emojis = (_vala_array_free (self->priv->_recently_used_custom_emojis, self->priv->_recently_used_custom_emojis_length1, (GDestroyNotify) g_free), NULL);
	self->priv->_recent_searches = (_vala_array_free (self->priv->_recent_searches, self->priv->_recent_searches_length1, (GDestroyNotify) g_free), NULL);
	self->priv->_notification_filters = (_vala_array_free (self->priv->_notification_filters, self->priv->_notification_filters_length1, (GDestroyNotify) g_free), NULL);
	self->priv->_favorite_lists_ids = (_vala_array_free (self->priv->_favorite_lists_ids, self->priv->_favorite_lists_ids_length1, (GDestroyNotify) g_free), NULL);
	self->priv->_favorite_tags_ids = (_vala_array_free (self->priv->_favorite_tags_ids, self->priv->_favorite_tags_ids_length1, (GDestroyNotify) g_free), NULL);
	self->priv->_hashtag_lists = (_vala_array_free (self->priv->_hashtag_lists, self->priv->_hashtag_lists_length1, (GDestroyNotify) g_free), NULL);
	G_OBJECT_CLASS (tuba_settings_account_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_settings_account_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaSettingsAccountClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_settings_account_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaSettingsAccount), 0, (GInstanceInitFunc) tuba_settings_account_instance_init, NULL };
	GType tuba_settings_account_type_id;
	tuba_settings_account_type_id = g_type_register_static (g_settings_get_type (), "TubaSettingsAccount", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaSettingsAccount_private_offset = g_type_add_instance_private (tuba_settings_account_type_id, sizeof (TubaSettingsAccountPrivate));
	return tuba_settings_account_type_id;
}

GType
tuba_settings_account_get_type (void)
{
	static GType tuba_settings_account_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_settings_account_type_id__once)) {
		GType tuba_settings_account_type_id;
		tuba_settings_account_type_id = tuba_settings_account_get_type_once ();
		g_once_init_leave_pointer (&tuba_settings_account_type_id__once, tuba_settings_account_type_id);
	}
	return tuba_settings_account_type_id__once;
}

static void
_vala_tuba_settings_account_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	TubaSettingsAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_SETTINGS_TYPE_ACCOUNT, TubaSettingsAccount);
	switch (property_id) {
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_QUOTE_POLICY_PROPERTY:
		g_value_set_string (value, tuba_settings_account_get_default_quote_policy (self));
		break;
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_LANGUAGE_PROPERTY:
		g_value_set_string (value, tuba_settings_account_get_default_language (self));
		break;
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_POST_VISIBILITY_PROPERTY:
		g_value_set_string (value, tuba_settings_account_get_default_post_visibility (self));
		break;
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_CONTENT_TYPE_PROPERTY:
		g_value_set_string (value, tuba_settings_account_get_default_content_type (self));
		break;
		case TUBA_SETTINGS_ACCOUNT_ACCOUNT_SUGGESTIONS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_account_get_account_suggestions (self));
		break;
		case TUBA_SETTINGS_ACCOUNT_MUTED_NOTIFICATION_TYPES_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_muted_notification_types (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_recently_used_custom_emojis (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_RECENT_SEARCHES_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_recent_searches (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_NOTIFICATION_FILTERS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_notification_filters (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_FAVORITE_LISTS_IDS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_favorite_lists_ids (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_FAVORITE_TAGS_IDS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_favorite_tags_ids (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_HASHTAG_LISTS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_account_get_hashtag_lists (self, &length));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_UNIFIEDPUSH_ENABLED_PROPERTY:
		g_value_set_boolean (value, tuba_settings_account_get_unifiedpush_enabled (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_settings_account_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	TubaSettingsAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_SETTINGS_TYPE_ACCOUNT, TubaSettingsAccount);
	switch (property_id) {
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_QUOTE_POLICY_PROPERTY:
		tuba_settings_account_set_default_quote_policy (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_LANGUAGE_PROPERTY:
		tuba_settings_account_set_default_language (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_POST_VISIBILITY_PROPERTY:
		tuba_settings_account_set_default_post_visibility (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_ACCOUNT_DEFAULT_CONTENT_TYPE_PROPERTY:
		tuba_settings_account_set_default_content_type (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_ACCOUNT_ACCOUNT_SUGGESTIONS_PROPERTY:
		tuba_settings_account_set_account_suggestions (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_ACCOUNT_MUTED_NOTIFICATION_TYPES_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_muted_notification_types (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_recently_used_custom_emojis (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_RECENT_SEARCHES_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_recent_searches (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_NOTIFICATION_FILTERS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_notification_filters (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_FAVORITE_LISTS_IDS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_favorite_lists_ids (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_FAVORITE_TAGS_IDS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_favorite_tags_ids (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_HASHTAG_LISTS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_account_set_hashtag_lists (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_ACCOUNT_UNIFIEDPUSH_ENABLED_PROPERTY:
		tuba_settings_account_set_unifiedpush_enabled (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_settings_class_init (TubaSettingsClass * klass,
                          gpointer klass_data)
{
	tuba_settings_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaSettings_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_settings_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_settings_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_settings_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACTIVE_ACCOUNT_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_ACTIVE_ACCOUNT_PROPERTY] = g_param_spec_string ("active-account", "active-account", "active-account", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_DEFAULT_LANGUAGE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_LANGUAGE_PROPERTY] = g_param_spec_string ("default-language", "default-language", "default-language", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_DEFAULT_QUOTE_POLICY_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_QUOTE_POLICY_PROPERTY] = g_param_spec_string ("default-quote-policy", "default-quote-policy", "default-quote-policy", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_DEFAULT_POST_VISIBILITY_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_POST_VISIBILITY_PROPERTY] = g_param_spec_string ("default-post-visibility", "default-post-visibility", "default-post-visibility", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_DEFAULT_CONTENT_TYPE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_DEFAULT_CONTENT_TYPE_PROPERTY] = g_param_spec_string ("default-content-type", "default-content-type", "default-content-type", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ACCOUNT_SUGGESTIONS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_ACCOUNT_SUGGESTIONS_PROPERTY] = g_param_spec_boolean ("account-suggestions", "account-suggestions", "account-suggestions", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_UNIFIEDPUSH_ENABLED_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_UNIFIEDPUSH_ENABLED_PROPERTY] = g_param_spec_boolean ("unifiedpush-enabled", "unifiedpush-enabled", "unifiedpush-enabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_MUTED_NOTIFICATION_TYPES_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_MUTED_NOTIFICATION_TYPES_PROPERTY] = g_param_spec_boxed ("muted-notification-types", "muted-notification-types", "muted-notification-types", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY] = g_param_spec_boxed ("recently-used-custom-emojis", "recently-used-custom-emojis", "recently-used-custom-emojis", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_RECENT_SEARCHES_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_RECENT_SEARCHES_PROPERTY] = g_param_spec_boxed ("recent-searches", "recent-searches", "recent-searches", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_NOTIFICATION_FILTERS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_NOTIFICATION_FILTERS_PROPERTY] = g_param_spec_boxed ("notification-filters", "notification-filters", "notification-filters", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_FAVORITE_LISTS_IDS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_FAVORITE_LISTS_IDS_PROPERTY] = g_param_spec_boxed ("favorite-lists-ids", "favorite-lists-ids", "favorite-lists-ids", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_FAVORITE_TAGS_IDS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_FAVORITE_TAGS_IDS_PROPERTY] = g_param_spec_boxed ("favorite-tags-ids", "favorite-tags-ids", "favorite-tags-ids", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_HASHTAG_LISTS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_HASHTAG_LISTS_PROPERTY] = g_param_spec_boxed ("hashtag-lists", "hashtag-lists", "hashtag-lists", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_COLOR_SCHEME_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_COLOR_SCHEME_PROPERTY] = g_param_spec_enum ("color-scheme", "color-scheme", "color-scheme", TUBA_TYPE_COLOR_SCHEME, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_WORK_IN_BACKGROUND_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_WORK_IN_BACKGROUND_PROPERTY] = g_param_spec_boolean ("work-in-background", "work-in-background", "work-in-background", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_TIMELINE_PAGE_SIZE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_TIMELINE_PAGE_SIZE_PROPERTY] = g_param_spec_int ("timeline-page-size", "timeline-page-size", "timeline-page-size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_LIVE_UPDATES_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_LIVE_UPDATES_PROPERTY] = g_param_spec_boolean ("live-updates", "live-updates", "live-updates", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_PUBLIC_LIVE_UPDATES_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_PUBLIC_LIVE_UPDATES_PROPERTY] = g_param_spec_boolean ("public-live-updates", "public-live-updates", "public-live-updates", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_SHOW_SPOILERS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_SHOW_SPOILERS_PROPERTY] = g_param_spec_boolean ("show-spoilers", "show-spoilers", "show-spoilers", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_SHOW_PREVIEW_CARDS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_SHOW_PREVIEW_CARDS_PROPERTY] = g_param_spec_boolean ("show-preview-cards", "show-preview-cards", "show-preview-cards", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_LARGER_FONT_SIZE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_LARGER_FONT_SIZE_PROPERTY] = g_param_spec_boolean ("larger-font-size", "larger-font-size", "larger-font-size", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_LARGER_LINE_HEIGHT_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_LARGER_LINE_HEIGHT_PROPERTY] = g_param_spec_boolean ("larger-line-height", "larger-line-height", "larger-line-height", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_SCALE_EMOJI_HOVER_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_SCALE_EMOJI_HOVER_PROPERTY] = g_param_spec_boolean ("scale-emoji-hover", "scale-emoji-hover", "scale-emoji-hover", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_AGGRESSIVE_RESOLVING_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_AGGRESSIVE_RESOLVING_PROPERTY] = g_param_spec_boolean ("aggressive-resolving", "aggressive-resolving", "aggressive-resolving", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_STRIP_TRACKING_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_STRIP_TRACKING_PROPERTY] = g_param_spec_boolean ("strip-tracking", "strip-tracking", "strip-tracking", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_LETTERBOX_MEDIA_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_LETTERBOX_MEDIA_PROPERTY] = g_param_spec_boolean ("letterbox-media", "letterbox-media", "letterbox-media", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_MEDIA_VIEWER_EXPAND_PICTURES_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_MEDIA_VIEWER_EXPAND_PICTURES_PROPERTY] = g_param_spec_boolean ("media-viewer-expand-pictures", "media-viewer-expand-pictures", "media-viewer-expand-pictures", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ENLARGE_CUSTOM_EMOJIS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_ENLARGE_CUSTOM_EMOJIS_PROPERTY] = g_param_spec_boolean ("enlarge-custom-emojis", "enlarge-custom-emojis", "enlarge-custom-emojis", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_USE_BLURHASH_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_USE_BLURHASH_PROPERTY] = g_param_spec_boolean ("use-blurhash", "use-blurhash", "use-blurhash", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_SHOW_SENSITIVE_MEDIA_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_SHOW_SENSITIVE_MEDIA_PROPERTY] = g_param_spec_boolean ("show-sensitive-media", "show-sensitive-media", "show-sensitive-media", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_GROUP_PUSH_NOTIFICATIONS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_GROUP_PUSH_NOTIFICATIONS_PROPERTY] = g_param_spec_boolean ("group-push-notifications", "group-push-notifications", "group-push-notifications", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ADVANCED_BOOST_DIALOG_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_ADVANCED_BOOST_DIALOG_PROPERTY] = g_param_spec_boolean ("advanced-boost-dialog", "advanced-boost-dialog", "advanced-boost-dialog", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_REPLY_TO_OLD_POST_REMINDER_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_REPLY_TO_OLD_POST_REMINDER_PROPERTY] = g_param_spec_boolean ("reply-to-old-post-reminder", "reply-to-old-post-reminder", "reply-to-old-post-reminder", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_BOOST_ALT_TEXT_REMINDER_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_BOOST_ALT_TEXT_REMINDER_PROPERTY] = g_param_spec_boolean ("boost-alt-text-reminder", "boost-alt-text-reminder", "boost-alt-text-reminder", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_FETCH_REMOTE_MEDIA_REMINDER_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_FETCH_REMOTE_MEDIA_REMINDER_PROPERTY] = g_param_spec_boolean ("fetch-remote-media-reminder", "fetch-remote-media-reminder", "fetch-remote-media-reminder", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_FETCH_REMOTE_MEDIA_DEFAULT_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_FETCH_REMOTE_MEDIA_DEFAULT_PROPERTY] = g_param_spec_boolean ("fetch-remote-media-default", "fetch-remote-media-default", "fetch-remote-media-default", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_COPY_PRIVATE_LINK_REMINDER_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_COPY_PRIVATE_LINK_REMINDER_PROPERTY] = g_param_spec_boolean ("copy-private-link-reminder", "copy-private-link-reminder", "copy-private-link-reminder", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_SPELLCHECKER_ENABLED_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_SPELLCHECKER_ENABLED_PROPERTY] = g_param_spec_boolean ("spellchecker-enabled", "spellchecker-enabled", "spellchecker-enabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_DARKEN_IMAGES_ON_DARK_MODE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_DARKEN_IMAGES_ON_DARK_MODE_PROPERTY] = g_param_spec_boolean ("darken-images-on-dark-mode", "darken-images-on-dark-mode", "darken-images-on-dark-mode", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_MEDIA_VIEWER_LAST_USED_VOLUME_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_MEDIA_VIEWER_LAST_USED_VOLUME_PROPERTY] = g_param_spec_double ("media-viewer-last-used-volume", "media-viewer-last-used-volume", "media-viewer-last-used-volume", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_MONITOR_NETWORK_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_MONITOR_NETWORK_PROPERTY] = g_param_spec_boolean ("monitor-network", "monitor-network", "monitor-network", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_PROXY_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_PROXY_PROPERTY] = g_param_spec_string ("proxy", "proxy", "proxy", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_DIM_TRIVIAL_NOTIFICATIONS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_DIM_TRIVIAL_NOTIFICATIONS_PROPERTY] = g_param_spec_boolean ("dim-trivial-notifications", "dim-trivial-notifications", "dim-trivial-notifications", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_ANALYTICS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_ANALYTICS_PROPERTY] = g_param_spec_boolean ("analytics", "analytics", "analytics", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_UPDATE_CONTRIBUTORS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_UPDATE_CONTRIBUTORS_PROPERTY] = g_param_spec_boolean ("update-contributors", "update-contributors", "update-contributors", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_LAST_ANALYTICS_UPDATE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_LAST_ANALYTICS_UPDATE_PROPERTY] = g_param_spec_string ("last-analytics-update", "last-analytics-update", "last-analytics-update", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_LAST_CONTRIBUTORS_UPDATE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_LAST_CONTRIBUTORS_UPDATE_PROPERTY] = g_param_spec_string ("last-contributors-update", "last-contributors-update", "last-contributors-update", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_CONTRIBUTORS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_CONTRIBUTORS_PROPERTY] = g_param_spec_boxed ("contributors", "contributors", "contributors", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_STATUS_ARIA_VERBOSITY_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_STATUS_ARIA_VERBOSITY_PROPERTY] = g_param_spec_int ("status-aria-verbosity", "status-aria-verbosity", "status-aria-verbosity", G_MININT, G_MAXINT, 3, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_USE_IN_APP_BROWSER_IF_AVAILABLE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_USE_IN_APP_BROWSER_IF_AVAILABLE_PROPERTY] = g_param_spec_boolean ("use-in-app-browser-if-available", "use-in-app-browser-if-available", "use-in-app-browser-if-available", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_COLLAPSE_LONG_POSTS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_COLLAPSE_LONG_POSTS_PROPERTY] = g_param_spec_boolean ("collapse-long-posts", "collapse-long-posts", "collapse-long-posts", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_SHOW_INTERACTION_COUNTERS_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_SHOW_INTERACTION_COUNTERS_PROPERTY] = g_param_spec_boolean ("show-interaction-counters", "show-interaction-counters", "show-interaction-counters", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_EXTRACT_ALT_FROM_METADATA_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_EXTRACT_ALT_FROM_METADATA_PROPERTY] = g_param_spec_boolean ("extract-alt-from-metadata", "extract-alt-from-metadata", "extract-alt-from-metadata", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_SETTINGS_STATUS_FONT_SIZE_PROPERTY, tuba_settings_properties[TUBA_SETTINGS_STATUS_FONT_SIZE_PROPERTY] = g_param_spec_double ("status-font-size", "status-font-size", "status-font-size", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_settings_instance_init (TubaSettings * self,
                             gpointer klass)
{
	gchar* _tmp0_;
	gchar** _tmp1_;
	gchar** _tmp2_;
	self->priv = tuba_settings_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_active_account = _tmp0_;
	_tmp1_ = g_new0 (gchar*, 0 + 1);
	self->priv->_contributors = _tmp1_;
	self->priv->_contributors_length1 = 0;
	self->priv->__contributors_size_ = self->priv->_contributors_length1;
	self->priv->_status_aria_verbosity = 3;
	_tmp2_ = g_new0 (gchar*, 0 + 1);
	self->priv->apply_instantly_keys = _tmp2_;
	self->priv->apply_instantly_keys_length1 = 0;
	self->priv->_apply_instantly_keys_size_ = self->priv->apply_instantly_keys_length1;
}

static void
tuba_settings_finalize (GObject * obj)
{
	TubaSettings * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_TYPE_SETTINGS, TubaSettings);
	_g_object_unref0 (self->priv->_active_account_settings);
	_g_free0 (self->priv->_active_account);
	_g_free0 (self->priv->_proxy);
	_g_free0 (self->priv->_last_analytics_update);
	_g_free0 (self->priv->_last_contributors_update);
	self->priv->_contributors = (_vala_array_free (self->priv->_contributors, self->priv->_contributors_length1, (GDestroyNotify) g_free), NULL);
	self->priv->apply_instantly_keys = (_vala_array_free (self->priv->apply_instantly_keys, self->priv->apply_instantly_keys_length1, (GDestroyNotify) g_free), NULL);
	G_OBJECT_CLASS (tuba_settings_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_settings_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaSettingsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_settings_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaSettings), 0, (GInstanceInitFunc) tuba_settings_instance_init, NULL };
	GType tuba_settings_type_id;
	tuba_settings_type_id = g_type_register_static (g_settings_get_type (), "TubaSettings", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaSettings_private_offset = g_type_add_instance_private (tuba_settings_type_id, sizeof (TubaSettingsPrivate));
	return tuba_settings_type_id;
}

GType
tuba_settings_get_type (void)
{
	static GType tuba_settings_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_settings_type_id__once)) {
		GType tuba_settings_type_id;
		tuba_settings_type_id = tuba_settings_get_type_once ();
		g_once_init_leave_pointer (&tuba_settings_type_id__once, tuba_settings_type_id);
	}
	return tuba_settings_type_id__once;
}

static void
_vala_tuba_settings_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	TubaSettings * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_TYPE_SETTINGS, TubaSettings);
	switch (property_id) {
		case TUBA_SETTINGS_ACTIVE_ACCOUNT_PROPERTY:
		g_value_set_string (value, tuba_settings_get_active_account (self));
		break;
		case TUBA_SETTINGS_DEFAULT_LANGUAGE_PROPERTY:
		g_value_set_string (value, tuba_settings_get_default_language (self));
		break;
		case TUBA_SETTINGS_DEFAULT_QUOTE_POLICY_PROPERTY:
		g_value_set_string (value, tuba_settings_get_default_quote_policy (self));
		break;
		case TUBA_SETTINGS_DEFAULT_POST_VISIBILITY_PROPERTY:
		g_value_set_string (value, tuba_settings_get_default_post_visibility (self));
		break;
		case TUBA_SETTINGS_DEFAULT_CONTENT_TYPE_PROPERTY:
		g_value_set_string (value, tuba_settings_get_default_content_type (self));
		break;
		case TUBA_SETTINGS_ACCOUNT_SUGGESTIONS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_account_suggestions (self));
		break;
		case TUBA_SETTINGS_UNIFIEDPUSH_ENABLED_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_unifiedpush_enabled (self));
		break;
		case TUBA_SETTINGS_MUTED_NOTIFICATION_TYPES_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_muted_notification_types (self, &length));
		}
		break;
		case TUBA_SETTINGS_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_recently_used_custom_emojis (self, &length));
		}
		break;
		case TUBA_SETTINGS_RECENT_SEARCHES_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_recent_searches (self, &length));
		}
		break;
		case TUBA_SETTINGS_NOTIFICATION_FILTERS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_notification_filters (self, &length));
		}
		break;
		case TUBA_SETTINGS_FAVORITE_LISTS_IDS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_favorite_lists_ids (self, &length));
		}
		break;
		case TUBA_SETTINGS_FAVORITE_TAGS_IDS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_favorite_tags_ids (self, &length));
		}
		break;
		case TUBA_SETTINGS_HASHTAG_LISTS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_hashtag_lists (self, &length));
		}
		break;
		case TUBA_SETTINGS_COLOR_SCHEME_PROPERTY:
		g_value_set_enum (value, tuba_settings_get_color_scheme (self));
		break;
		case TUBA_SETTINGS_WORK_IN_BACKGROUND_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_work_in_background (self));
		break;
		case TUBA_SETTINGS_TIMELINE_PAGE_SIZE_PROPERTY:
		g_value_set_int (value, tuba_settings_get_timeline_page_size (self));
		break;
		case TUBA_SETTINGS_LIVE_UPDATES_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_live_updates (self));
		break;
		case TUBA_SETTINGS_PUBLIC_LIVE_UPDATES_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_public_live_updates (self));
		break;
		case TUBA_SETTINGS_SHOW_SPOILERS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_show_spoilers (self));
		break;
		case TUBA_SETTINGS_SHOW_PREVIEW_CARDS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_show_preview_cards (self));
		break;
		case TUBA_SETTINGS_LARGER_FONT_SIZE_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_larger_font_size (self));
		break;
		case TUBA_SETTINGS_LARGER_LINE_HEIGHT_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_larger_line_height (self));
		break;
		case TUBA_SETTINGS_SCALE_EMOJI_HOVER_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_scale_emoji_hover (self));
		break;
		case TUBA_SETTINGS_AGGRESSIVE_RESOLVING_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_aggressive_resolving (self));
		break;
		case TUBA_SETTINGS_STRIP_TRACKING_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_strip_tracking (self));
		break;
		case TUBA_SETTINGS_LETTERBOX_MEDIA_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_letterbox_media (self));
		break;
		case TUBA_SETTINGS_MEDIA_VIEWER_EXPAND_PICTURES_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_media_viewer_expand_pictures (self));
		break;
		case TUBA_SETTINGS_ENLARGE_CUSTOM_EMOJIS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_enlarge_custom_emojis (self));
		break;
		case TUBA_SETTINGS_USE_BLURHASH_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_use_blurhash (self));
		break;
		case TUBA_SETTINGS_SHOW_SENSITIVE_MEDIA_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_show_sensitive_media (self));
		break;
		case TUBA_SETTINGS_GROUP_PUSH_NOTIFICATIONS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_group_push_notifications (self));
		break;
		case TUBA_SETTINGS_ADVANCED_BOOST_DIALOG_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_advanced_boost_dialog (self));
		break;
		case TUBA_SETTINGS_REPLY_TO_OLD_POST_REMINDER_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_reply_to_old_post_reminder (self));
		break;
		case TUBA_SETTINGS_BOOST_ALT_TEXT_REMINDER_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_boost_alt_text_reminder (self));
		break;
		case TUBA_SETTINGS_FETCH_REMOTE_MEDIA_REMINDER_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_fetch_remote_media_reminder (self));
		break;
		case TUBA_SETTINGS_FETCH_REMOTE_MEDIA_DEFAULT_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_fetch_remote_media_default (self));
		break;
		case TUBA_SETTINGS_COPY_PRIVATE_LINK_REMINDER_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_copy_private_link_reminder (self));
		break;
		case TUBA_SETTINGS_SPELLCHECKER_ENABLED_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_spellchecker_enabled (self));
		break;
		case TUBA_SETTINGS_DARKEN_IMAGES_ON_DARK_MODE_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_darken_images_on_dark_mode (self));
		break;
		case TUBA_SETTINGS_MEDIA_VIEWER_LAST_USED_VOLUME_PROPERTY:
		g_value_set_double (value, tuba_settings_get_media_viewer_last_used_volume (self));
		break;
		case TUBA_SETTINGS_MONITOR_NETWORK_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_monitor_network (self));
		break;
		case TUBA_SETTINGS_PROXY_PROPERTY:
		g_value_set_string (value, tuba_settings_get_proxy (self));
		break;
		case TUBA_SETTINGS_DIM_TRIVIAL_NOTIFICATIONS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_dim_trivial_notifications (self));
		break;
		case TUBA_SETTINGS_ANALYTICS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_analytics (self));
		break;
		case TUBA_SETTINGS_UPDATE_CONTRIBUTORS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_update_contributors (self));
		break;
		case TUBA_SETTINGS_LAST_ANALYTICS_UPDATE_PROPERTY:
		g_value_set_string (value, tuba_settings_get_last_analytics_update (self));
		break;
		case TUBA_SETTINGS_LAST_CONTRIBUTORS_UPDATE_PROPERTY:
		g_value_set_string (value, tuba_settings_get_last_contributors_update (self));
		break;
		case TUBA_SETTINGS_CONTRIBUTORS_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_settings_get_contributors (self, &length));
		}
		break;
		case TUBA_SETTINGS_STATUS_ARIA_VERBOSITY_PROPERTY:
		g_value_set_int (value, tuba_settings_get_status_aria_verbosity (self));
		break;
		case TUBA_SETTINGS_USE_IN_APP_BROWSER_IF_AVAILABLE_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_use_in_app_browser_if_available (self));
		break;
		case TUBA_SETTINGS_COLLAPSE_LONG_POSTS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_collapse_long_posts (self));
		break;
		case TUBA_SETTINGS_SHOW_INTERACTION_COUNTERS_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_show_interaction_counters (self));
		break;
		case TUBA_SETTINGS_EXTRACT_ALT_FROM_METADATA_PROPERTY:
		g_value_set_boolean (value, tuba_settings_get_extract_alt_from_metadata (self));
		break;
		case TUBA_SETTINGS_STATUS_FONT_SIZE_PROPERTY:
		g_value_set_double (value, tuba_settings_get_status_font_size (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_settings_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	TubaSettings * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_TYPE_SETTINGS, TubaSettings);
	switch (property_id) {
		case TUBA_SETTINGS_ACTIVE_ACCOUNT_PROPERTY:
		tuba_settings_set_active_account (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_DEFAULT_LANGUAGE_PROPERTY:
		tuba_settings_set_default_language (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_DEFAULT_QUOTE_POLICY_PROPERTY:
		tuba_settings_set_default_quote_policy (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_DEFAULT_POST_VISIBILITY_PROPERTY:
		tuba_settings_set_default_post_visibility (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_DEFAULT_CONTENT_TYPE_PROPERTY:
		tuba_settings_set_default_content_type (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_ACCOUNT_SUGGESTIONS_PROPERTY:
		tuba_settings_set_account_suggestions (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_UNIFIEDPUSH_ENABLED_PROPERTY:
		tuba_settings_set_unifiedpush_enabled (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_MUTED_NOTIFICATION_TYPES_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_muted_notification_types (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_RECENTLY_USED_CUSTOM_EMOJIS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_recently_used_custom_emojis (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_RECENT_SEARCHES_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_recent_searches (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_NOTIFICATION_FILTERS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_notification_filters (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_FAVORITE_LISTS_IDS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_favorite_lists_ids (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_FAVORITE_TAGS_IDS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_favorite_tags_ids (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_HASHTAG_LISTS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_hashtag_lists (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_COLOR_SCHEME_PROPERTY:
		tuba_settings_set_color_scheme (self, g_value_get_enum (value));
		break;
		case TUBA_SETTINGS_WORK_IN_BACKGROUND_PROPERTY:
		tuba_settings_set_work_in_background (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_TIMELINE_PAGE_SIZE_PROPERTY:
		tuba_settings_set_timeline_page_size (self, g_value_get_int (value));
		break;
		case TUBA_SETTINGS_LIVE_UPDATES_PROPERTY:
		tuba_settings_set_live_updates (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_PUBLIC_LIVE_UPDATES_PROPERTY:
		tuba_settings_set_public_live_updates (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_SHOW_SPOILERS_PROPERTY:
		tuba_settings_set_show_spoilers (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_SHOW_PREVIEW_CARDS_PROPERTY:
		tuba_settings_set_show_preview_cards (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_LARGER_FONT_SIZE_PROPERTY:
		tuba_settings_set_larger_font_size (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_LARGER_LINE_HEIGHT_PROPERTY:
		tuba_settings_set_larger_line_height (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_SCALE_EMOJI_HOVER_PROPERTY:
		tuba_settings_set_scale_emoji_hover (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_AGGRESSIVE_RESOLVING_PROPERTY:
		tuba_settings_set_aggressive_resolving (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_STRIP_TRACKING_PROPERTY:
		tuba_settings_set_strip_tracking (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_LETTERBOX_MEDIA_PROPERTY:
		tuba_settings_set_letterbox_media (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_MEDIA_VIEWER_EXPAND_PICTURES_PROPERTY:
		tuba_settings_set_media_viewer_expand_pictures (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_ENLARGE_CUSTOM_EMOJIS_PROPERTY:
		tuba_settings_set_enlarge_custom_emojis (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_USE_BLURHASH_PROPERTY:
		tuba_settings_set_use_blurhash (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_SHOW_SENSITIVE_MEDIA_PROPERTY:
		tuba_settings_set_show_sensitive_media (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_GROUP_PUSH_NOTIFICATIONS_PROPERTY:
		tuba_settings_set_group_push_notifications (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_ADVANCED_BOOST_DIALOG_PROPERTY:
		tuba_settings_set_advanced_boost_dialog (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_REPLY_TO_OLD_POST_REMINDER_PROPERTY:
		tuba_settings_set_reply_to_old_post_reminder (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_BOOST_ALT_TEXT_REMINDER_PROPERTY:
		tuba_settings_set_boost_alt_text_reminder (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_FETCH_REMOTE_MEDIA_REMINDER_PROPERTY:
		tuba_settings_set_fetch_remote_media_reminder (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_FETCH_REMOTE_MEDIA_DEFAULT_PROPERTY:
		tuba_settings_set_fetch_remote_media_default (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_COPY_PRIVATE_LINK_REMINDER_PROPERTY:
		tuba_settings_set_copy_private_link_reminder (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_SPELLCHECKER_ENABLED_PROPERTY:
		tuba_settings_set_spellchecker_enabled (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_DARKEN_IMAGES_ON_DARK_MODE_PROPERTY:
		tuba_settings_set_darken_images_on_dark_mode (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_MEDIA_VIEWER_LAST_USED_VOLUME_PROPERTY:
		tuba_settings_set_media_viewer_last_used_volume (self, g_value_get_double (value));
		break;
		case TUBA_SETTINGS_MONITOR_NETWORK_PROPERTY:
		tuba_settings_set_monitor_network (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_PROXY_PROPERTY:
		tuba_settings_set_proxy (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_DIM_TRIVIAL_NOTIFICATIONS_PROPERTY:
		tuba_settings_set_dim_trivial_notifications (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_ANALYTICS_PROPERTY:
		tuba_settings_set_analytics (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_UPDATE_CONTRIBUTORS_PROPERTY:
		tuba_settings_set_update_contributors (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_LAST_ANALYTICS_UPDATE_PROPERTY:
		tuba_settings_set_last_analytics_update (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_LAST_CONTRIBUTORS_UPDATE_PROPERTY:
		tuba_settings_set_last_contributors_update (self, g_value_get_string (value));
		break;
		case TUBA_SETTINGS_CONTRIBUTORS_PROPERTY:
		{
			gpointer boxed;
			boxed = g_value_get_boxed (value);
			tuba_settings_set_contributors (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
		}
		break;
		case TUBA_SETTINGS_STATUS_ARIA_VERBOSITY_PROPERTY:
		tuba_settings_set_status_aria_verbosity (self, g_value_get_int (value));
		break;
		case TUBA_SETTINGS_USE_IN_APP_BROWSER_IF_AVAILABLE_PROPERTY:
		tuba_settings_set_use_in_app_browser_if_available (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_COLLAPSE_LONG_POSTS_PROPERTY:
		tuba_settings_set_collapse_long_posts (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_SHOW_INTERACTION_COUNTERS_PROPERTY:
		tuba_settings_set_show_interaction_counters (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_EXTRACT_ALT_FROM_METADATA_PROPERTY:
		tuba_settings_set_extract_alt_from_metadata (self, g_value_get_boolean (value));
		break;
		case TUBA_SETTINGS_STATUS_FONT_SIZE_PROPERTY:
		tuba_settings_set_status_font_size (self, g_value_get_double (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

gchar*
tuba_color_scheme_to_string (TubaColorScheme self)
{
	gchar* result;
	switch (self) {
		case TUBA_COLOR_SCHEME_SYSTEM:
		{
			gchar* _tmp0_;
			_tmp0_ = g_strdup (_ ("Follow System"));
			result = _tmp0_;
			return result;
		}
		case TUBA_COLOR_SCHEME_LIGHT:
		{
			gchar* _tmp1_;
			_tmp1_ = g_strdup (_ ("Light"));
			result = _tmp1_;
			return result;
		}
		case TUBA_COLOR_SCHEME_DARK:
		{
			gchar* _tmp2_;
			_tmp2_ = g_strdup (_ ("Dark"));
			result = _tmp2_;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

AdwColorScheme
tuba_color_scheme_to_adwaita_scheme (TubaColorScheme self)
{
	AdwColorScheme result;
	switch (self) {
		case TUBA_COLOR_SCHEME_SYSTEM:
		{
			result = ADW_COLOR_SCHEME_DEFAULT;
			return result;
		}
		case TUBA_COLOR_SCHEME_LIGHT:
		{
			result = ADW_COLOR_SCHEME_FORCE_LIGHT;
			return result;
		}
		case TUBA_COLOR_SCHEME_DARK:
		{
			result = ADW_COLOR_SCHEME_FORCE_DARK;
			return result;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
}

 G_GNUC_NO_INLINE static GType
tuba_color_scheme_get_type_once (void)
{
	static const GEnumValue values[] = {{TUBA_COLOR_SCHEME_SYSTEM, "TUBA_COLOR_SCHEME_SYSTEM", "system"}, {TUBA_COLOR_SCHEME_LIGHT, "TUBA_COLOR_SCHEME_LIGHT", "light"}, {TUBA_COLOR_SCHEME_DARK, "TUBA_COLOR_SCHEME_DARK", "dark"}, {0, NULL, NULL}};
	GType tuba_color_scheme_type_id;
	tuba_color_scheme_type_id = g_enum_register_static ("TubaColorScheme", values);
	return tuba_color_scheme_type_id;
}

GType
tuba_color_scheme_get_type (void)
{
	static GType tuba_color_scheme_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_color_scheme_type_id__once)) {
		GType tuba_color_scheme_type_id;
		tuba_color_scheme_type_id = tuba_color_scheme_get_type_once ();
		g_once_init_leave_pointer (&tuba_color_scheme_type_id__once, tuba_color_scheme_type_id);
	}
	return tuba_color_scheme_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

